/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, ElementRef } from '@angular/core';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { ContextService } from '../common/provider.service';
import { ColumnMenuItemBase } from './column-menu-item-base';
import * as i0 from "@angular/core";
/**
 * Represents the column-menu item for editing column filters in the Grid. [See example](slug:columnmenu_grid#toc-filter-item).
 *
 * Place this component inside a [`ColumnMenuTemplate`]({% slug api_grid_columnmenutemplatedirective %}) directive.
 * To register the component as a known column menu item, set the [`ColumnMenuService`]({% slug api_grid_columnmenuservice %}) that the template passes to the `service` input of the `kendo-grid-columnmenu-filter` component. [See example](slug:columnmenu_grid#toc-customizing-the-content).
 *
 * @example
 * ```html
 * <kendo-grid [columnMenu]="true" ...>
 *   <ng-template kendoGridColumnMenuTemplate let-service="service">
 *     <kendo-grid-columnmenu-filter [service]="service">
 *     </kendo-grid-columnmenu-filter>
 *   </ng-template>
 * </kendo-grid>
 * ```
 * @example
 * ```html
 * <kendo-grid-column field="ProductName">
 *   <ng-template kendoGridColumnMenuTemplate let-service="service">
 *     <kendo-grid-columnmenu-filter [service]="service">
 *     </kendo-grid-columnmenu-filter>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 */
export declare class ColumnMenuFilterComponent extends ColumnMenuItemBase {
    ctx: ContextService;
    private hostElement;
    /**
     * Emits when the content expands.
     */
    expand: EventEmitter<any>;
    /**
     * Emits when the content collapses.
     */
    collapse: EventEmitter<any>;
    /**
     * Specifies if the content is expanded.
     * @default false
     */
    expanded: boolean;
    /**
     * Specifies if this is the last item in the menu.
     * @hidden
     */
    isLast: boolean;
    /**
     * Sets the CSS class for the actions container.
     * @hidden
     */
    actionsClass: string;
    /**
     * Defines the SVG icon for the filter.
     */
    filterIcon: SVGIcon;
    constructor(ctx: ContextService, hostElement: ElementRef);
    /**
     * @hidden
     */
    onCollapse(): void;
    /**
     * @hidden
     */
    onExpand(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuFilterComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnMenuFilterComponent, "kendo-grid-columnmenu-filter", never, { "expanded": { "alias": "expanded"; "required": false; }; "isLast": { "alias": "isLast"; "required": false; }; }, { "expand": "expand"; "collapse": "collapse"; }, never, never, true, never>;
}
