/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Observable } from 'rxjs';
import { ColumnBase } from '../columns/column-base';
/**
 * Defines the type for the `resizable` property. [See example](slug:resizing_columns_grid#constrained-mode)
 *
 * The possible values are:
 *
 * * `constrained`&mdash;Adjacent columns resize only up to their outer borders.
 * * `unconstrained`&mdash;Columns resize relative to the entire component.
 *
 * @example
 * ```html
 * <kendo-grid [kendoGridBinding]="gridData" [height]="370" resizable="constrained">
 *     <kendo-grid-column field="ProductID" title="ID"></kendo-grid-column>
 *     ...
 * </kendo-grid>
 * ```
 */
export type ResizeMode = 'unconstrained' | 'constrained';
/**
 * Represents the returned type of the `columnResize` event.
 */
export interface ColumnResizeArgs {
    /**
     * Specifies the resized column.
     */
    column: ColumnBase;
    /**
     * Specifies the new width (in pixels) of the column.
     */
    newWidth?: number;
    /**
     * Specifies the actual width (in pixels) of the column before resizing.
     */
    oldWidth: number;
}
/**
 * @hidden
 */
export type ActionType = 'start' | 'resizeColumn' | 'resizeTable' | 'end' | 'autoFitComplete' | 'triggerAutoFit';
/**
 * @hidden
 */
export interface ColumnResizeAction {
    columns: Array<ColumnBase>;
    delta?: number;
    deltaPercent?: number;
    locked?: boolean;
    resizedColumns?: Array<ColumnResizeArgs>;
    type: ActionType;
    widths?: Array<Array<number>>;
}
/**
 * @hidden
 */
export interface AutoFitInfo {
    column: ColumnBase;
    headerIndex: number;
    index: number;
    isLastInSpan: boolean;
    isParentSpan: boolean;
    level: number;
}
/**
 * @hidden
 */
export type AutoFitObservable = Observable<Array<number>>;
/**
 * @hidden
 */
export type AutoFitFn = (columns: Array<AutoFitInfo>) => AutoFitObservable;
