/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import { ColumnBase } from './column-base';
import { CellTemplateDirective } from '../rendering/cell-template.directive';
import { IdService } from '../common/id.service';
import { SelectionService } from '../selection/selection.service';
import { CellSelectionService } from '../selection/cell-selection.service';
import { CellRowspanFn } from './cell-rowspan';
import * as i0 from "@angular/core";
/**
 * Represents the checkbox column for selecting rows in the Grid. [See example](slug:grid_row_selection#toc-select-all-checkbox).
 *
 * Use this column to add checkboxes for row selection.
 *
 * @example
 * ```html
 * <kendo-grid [selectable]="{enabled: true, checkboxOnly: true}">
 *   <kendo-grid-checkbox-column title="Select"></kendo-grid-checkbox-column>
 *   <kendo-grid-column field="ID"></kendo-grid-column>
 * </kendo-grid>
 * ```
 */
export declare class CheckboxColumnComponent extends ColumnBase {
    private selectionService;
    private cellSelectionService;
    parent?: ColumnBase;
    /**
     * Shows a select-all `kendoGridSelectAllCheckbox` checkbox in the header.
     */
    showSelectAll: boolean;
    /**
     * Shows checkboxes for rows marked as non-selectable. By default, these checkboxes are visible and disabled.
     */
    showDisabledCheckbox: boolean;
    readonly isCheckboxColumn: boolean;
    template: CellTemplateDirective;
    constructor(selectionService: SelectionService, cellSelectionService: CellSelectionService, parent?: ColumnBase, idService?: IdService);
    get templateRef(): TemplateRef<any>;
    /**
     * @hidden
     */
    rowSelectable(rowIdx: number): boolean;
    /**
     * Defines a function to determine the rowspan of each column cell.
     */
    set cellRowspan(cellRowspan: CellRowspanFn);
    get cellRowspan(): CellRowspanFn;
    static ɵfac: i0.ɵɵFactoryDeclaration<CheckboxColumnComponent, [null, null, { optional: true; host: true; skipSelf: true; }, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CheckboxColumnComponent, "kendo-grid-checkbox-column", never, { "showSelectAll": { "alias": "showSelectAll"; "required": false; }; "showDisabledCheckbox": { "alias": "showDisabledCheckbox"; "required": false; }; }, {}, ["template"], never, true, never>;
}
