/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { GridComponent } from "../grid.component";
/**
 * Provides arguments for the [`cellClick`](slug:api_grid_gridcomponent#toc-cellclick) event.
 * Use this event to get details about the clicked cell in the Grid.
 *
 */
export interface CellClickEvent {
    /**
     * The column of the clicked cell.
     */
    column: any;
    /**
     * The column index of the clicked cell.
     */
    columnIndex: number;
    /**
     * The data item for the row containing the clicked cell.
     */
    dataItem: any;
    /**
     * Indicates if the cell is in edit mode.
     */
    isEdited: boolean;
    /**
     * The original DOM event that triggered the cell click.
     */
    originalEvent: any;
    /**
     * The row index of the clicked cell.
     */
    rowIndex: number;
    /**
     * The `GridComponent` instance.
     */
    sender: GridComponent;
    /**
     * The type of event that triggered the cell click.
     */
    type: 'click' | 'contextmenu';
}
