/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Observable } from "rxjs";
/**
 * A function that is called to confirm if the `dataItem` will be removed.
 *
 * @example
 * ```html
 * <kendo-grid [kendoGridTemplateEditing]="createNewProduct" [removeConfirmation]="confirmRemove" >
 *   <kendo-grid-column field="name" title="Name"></kendo-grid-column>
 * </kendo-grid>
 * ```
 * ```typescript
 * confirmRemove(dataItem: any): boolean {
 *   // Return a boolean, Promise, or Observable indicating if the item should be removed.
 * }
 * ```
 */
export type RemoveConfirmationCallback = (dataItem: any) => Promise<boolean> | Observable<boolean> | boolean;
