/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Configures size restrictions for a resizable Grid.
 * Use this interface to set min and max width and height for the Grid.
 */
export interface GridResizableSettings {
    /**
     * Sets the maximum width of the resizable Grid. Accepts all valid CSS [`max-width`](https://developer.mozilla.org/en-US/docs/Web/CSS/max-width) values.
     */
    maxWidth?: string;
    /**
     * Sets the maximum height of the resizable Grid. Accepts all valid CSS [`max-height`](https://developer.mozilla.org/en-US/docs/Web/CSS/max-height) values.
     */
    maxHeight?: string;
    /**
     * Sets the minimum width of the resizable Grid. Accepts all valid CSS [`min-width`](https://developer.mozilla.org/en-US/docs/Web/CSS/min-width) values.
     */
    minWidth?: string;
    /**
     * Sets the minimum height of the resizable Grid. Accepts all valid CSS [`min-height`](https://developer.mozilla.org/en-US/docs/Web/CSS/min-height) values.
     */
    minHeight?: string;
}
