/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PopupService, PopupRef } from '@progress/kendo-angular-popup';
import { Renderer2, NgZone, OnDestroy } from '@angular/core';
import { PreventableEvent } from './preventable-event';
import { Subject } from 'rxjs';
import { ScrollSyncService } from '../scrolling/scroll-sync.service';
import { ContextService } from './provider.service';
import { AdaptiveGridService } from './adaptiveness.service';
import * as i0 from "@angular/core";
/**
 * Arguments for the `close` event of the filter and column-menu popup.
 */
export declare class PopupCloseEvent extends PreventableEvent {
    /**
     * The original DOM event that causes the popup to close.
     */
    originalEvent: any;
    /**
     * @hidden
     */
    constructor(e: any);
}
/**
 * Provides popup management for filter and column menus.
 * Use this service to open and close popups for the Grid filter and column menus ([see example]({% slug filter_menu %}#toc-filter-menu-with-popup)).
 */
export declare class SinglePopupService implements OnDestroy {
    private popupService;
    private renderer;
    private ngZone;
    private ctx;
    private adaptiveGridService;
    /**
     * Emits when the filter or column menu popup is about to close because the user clicked outside.
     * Use this event to prevent the popup from closing.
     */
    readonly onClose: Subject<PopupCloseEvent>;
    private removeClick;
    private pointerEventsSub;
    private popupRef;
    private scrollSubscription;
    private canClosePopup;
    /**
     * @hidden
     */
    constructor(popupService: PopupService, renderer: Renderer2, ngZone: NgZone, scrollSyncService: ScrollSyncService, ctx: ContextService, adaptiveGridService: AdaptiveGridService);
    /**
     * @hidden
     */
    open(anchor: any, template: any, popupRef: PopupRef, popupClass?: string): PopupRef;
    /**
     * @hidden
     */
    destroy(): void;
    ngOnDestroy(): void;
    private detachClose;
    private attachClose;
    private attachMouseListeners;
    static ɵfac: i0.ɵɵFactoryDeclaration<SinglePopupService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SinglePopupService>;
}
