/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SortDescriptor, GroupDescriptor, CompositeFilterDescriptor } from '@progress/kendo-data-query';
/**
 * Provides the arguments for the `pageChange` event. [See example](slug:manual_paging_grid#toc-paging-local-data).
 */
export interface PageChangeEvent {
    /**
     * The number of records to skip.
     */
    skip: number;
    /**
     * The number of records to take.
     */
    take: number;
}
/**
 * Provides the arguments for the `dataStateChange` event
 * ([more information and examples](slug:data_operations_grid#toc-handling-multiple-data-operations)).
 */
export interface DataStateChangeEvent {
    /**
     * Sets how many records to skip.
     */
    skip: number;
    /**
     * Sets how many records to take.
     */
    take: number;
    /**
     * Defines the sort descriptors for sorting the data.
     */
    sort?: Array<SortDescriptor>;
    /**
     * Defines the group descriptors for grouping the data.
     */
    group?: Array<GroupDescriptor>;
    /**
     * Defines the filter descriptor for filtering the data.
     */
    filter?: CompositeFilterDescriptor;
}
