/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * The interface which must be extended when creating custom edit service.
 * This interface defines the methods that a custom editing service should implement to handle create, update, and remove operations on grid items.
 * Set the custom edit service to the `editService` input of the respective editing directive.
 * [See exampe](slug:editing_directives_grid#toc-custom-editing-service).
 */
export interface EditService {
    /**
     * Creates an item for a new row.
     * @param item The item to create.
     */
    create(item: any): void;
    /**
     * Updates an item for an existing row.
     * @param item The item to update.
     */
    update(item: any): void;
    /**
     * Removes an existing row.
     * @param item The item to remove.
     */
    remove(item: any): void;
    /**
     * Sets new values to an item.
     * @param target The target item.
     * @param source The source of values.
     */
    assignValues(target: any, source: any): void;
}
