/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef } from '@angular/core';
import { EditingDirectiveBase } from './editing-directive-base';
import { GridComponent } from '../grid.component';
import { LocalDataChangesService } from '../editing/local-data-changes.service';
import { CreateFormGroup } from '../common/create-form-group';
import * as i0 from "@angular/core";
/**
 * Represent the directive that manages in-cell editing operations in the Grid when using Reactive Forms ([see example]({% slug editing_directives_grid %}#toc-in-cell-editing)).
 *
 * @example
 * ```typescript
 * <kendo-grid [data]="data" kendoGridInCellEditing></kendo-grid>
 * ```
 * @remarks
 * Applied to: {@link GridComponent}.
 */
export declare class InCellEditingDirective extends EditingDirectiveBase {
    protected grid: GridComponent;
    protected localDataChangesService: LocalDataChangesService;
    protected cdr: ChangeDetectorRef;
    /**
     * Specifies the function that creates the `FormGroup` for the edited model.
     */
    createFormGroup: CreateFormGroup;
    constructor(grid: GridComponent, localDataChangesService: LocalDataChangesService, cdr: ChangeDetectorRef);
    protected createModel(args: any): any;
    protected saveModel({ dataItem, formGroup, isNew }: any): any;
    /**
     * @hidden
     */
    ngOnInit(): void;
    protected removeHandler(args: any): void;
    protected cellClickHandler(args: any): void;
    protected cellCloseHandler(args: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<InCellEditingDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<InCellEditingDirective, "[kendoGridInCellEditing]", never, { "createFormGroup": { "alias": "kendoGridInCellEditing"; "required": false; }; }, {}, never, never, true, never>;
}
