/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { RowEditingDirectiveBase } from './row-editing-directive-base';
import { GridComponent } from '../grid.component';
import { LocalDataChangesService } from '../editing/local-data-changes.service';
import * as i0 from "@angular/core";
/**
 * Represents the directive that manages editing operations in the Grid when using Template-Driven Angular Forms ([see example]({% slug editing_directives_grid %}#toc-template-editing-directive)).
 *
 * @example
 * ```typescript
 * <kendo-grid [data]="data" kendoGridTemplateEditing></kendo-grid>
 * ```
 * @remarks
 * Applied to: {@link GridComponent}.
 */
export declare class TemplateEditingDirective extends RowEditingDirectiveBase {
    protected grid: GridComponent;
    protected localDataChangesService: LocalDataChangesService;
    /**
     * Specifies the function that creates the `dataItem` for new rows.
     */
    createNewItem: Function;
    protected dataItem: any;
    protected originalValues: any;
    constructor(grid: GridComponent, localDataChangesService: LocalDataChangesService);
    protected editHandler(args: any): void;
    protected closeEditor(rowIndex: number): void;
    protected createModel(args: any): any;
    protected saveModel(args: any): any;
    protected clean(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TemplateEditingDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TemplateEditingDirective, "[kendoGridTemplateEditing]", never, { "createNewItem": { "alias": "kendoGridTemplateEditing"; "required": false; }; }, {}, never, never, true, never>;
}
