/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef, NgZone } from '@angular/core';
import { EditService } from './edit.service';
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { ContextService } from '../common/provider.service';
import { ToolbarEditingToolBase } from './toolbar-editing-tool-base.directive';
import * as i0 from "@angular/core";
/**
 * Represents the command for adding a new item to the Grid.
 * You can apply this directive to any `kendo-toolbar-button` element inside a ToolbarComponent used in the Grid.
 * When you click the toolbar button associated with the directive, the [`add`]({% slug api_grid_gridcomponent %}#toc-add) event triggers ([see example]({% slug basics_editing_grid %})).
 *
 * @example
 * ```html
 * <kendo-grid>
 *      <kendo-toolbar>
 *         <kendo-toolbar-button text="Add new" kendoGridAddTool></kendo-toolbar-button>
 *      </kendo-toolbar>
 * </kendo-grid>
 * ```
 * @remarks
 * Applied to: {@link ToolBarButtonComponent}.
 */
export declare class AddCommandToolbarDirective extends ToolbarEditingToolBase {
    editService: EditService;
    host: ToolBarButtonComponent;
    constructor(editService: EditService, host: ToolBarButtonComponent, ctx: ContextService, zone: NgZone, cdr: ChangeDetectorRef);
    ngOnInit(): void;
    /**
     * @hidden
     */
    onClick(e: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AddCommandToolbarDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AddCommandToolbarDirective, "[kendoGridAddTool]", never, {}, {}, never, never, true, never>;
}
