/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef, NgZone } from '@angular/core';
import { EditService } from './edit.service';
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { SelectionService } from '../selection/selection.service';
import { ContextService } from '../common/provider.service';
import { ToolbarEditingToolBase } from './toolbar-editing-tool-base.directive';
import * as i0 from "@angular/core";
/**
 * Represents the `cancel` command in the Grid.
 * Apply this directive to any `kendo-toolbar-button` element inside a ToolbarComponent in the Grid.
 *
 * When you click the toolbar button with this directive, the [`cancel`]({% slug api_grid_gridcomponent %}#toc-cancel) event triggers.
 *
 * @example
 * ```html
 * <kendo-grid>
 *      <kendo-toolbar>
 *         <kendo-toolbar-button text="Cancel" kendoGridCancelTool></kendo-toolbar-button>
 *      </kendo-toolbar>
 * </kendo-grid>
 * ```
 * @remarks
 * Applied to: {@link ToolBarButtonComponent}.
 */
export declare class CancelCommandToolbarDirective extends ToolbarEditingToolBase {
    editService: EditService;
    constructor(editService: EditService, host: ToolBarButtonComponent, selection: SelectionService, ctx: ContextService, zone: NgZone, cdr: ChangeDetectorRef);
    /**
     * @hidden
     */
    onClick(e: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CancelCommandToolbarDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<CancelCommandToolbarDirective, "[kendoGridCancelTool]", never, {}, {}, never, never, true, never>;
}
