/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Provides additional options for the [`editRow`]({% slug api_grid_gridcomponent %}#toc-editrow) method. [See example]({% slug editing_rowclick_grid %}#toc-managing-focus).
 *
 * @example
 * ```typescript
 * public onEdit(grid: GridComponent): void {
 *   grid.editRow(2, { skipFocus: true, columnIndex: 1 });
 * }
 * ```
 */
export interface EditRowOptions {
    /**
     * If set to `true`, skips focusing the row's edit element. Defaults to `false`.
     */
    skipFocus?: boolean;
    /**
     * Sets which column receives focus after the row editor opens. The first column receives focus by default.
     */
    columnIndex?: number;
}
