/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef, NgZone } from '@angular/core';
import { EditService } from './edit.service';
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { SelectionService } from '../selection/selection.service';
import { ContextService } from '../common/provider.service';
import { ToolbarEditingToolBase } from './toolbar-editing-tool-base.directive';
import * as i0 from "@angular/core";
/**
 * Represents the `remove` command in the Grid. Apply this directive to any `kendo-toolbar-button`
 * element inside a ToolbarComponent used in the Grid.
 *
 * When you click the toolbar button with this directive, the
 * [`remove`]({% slug api_grid_gridcomponent %}#toc-remove) event fires.
 *
 * @example
 * ```html
 * <kendo-grid>
 *   <kendo-toolbar>
 *      <kendo-toolbar-button text="Remove row" kendoGridRemoveTool></kendo-toolbar-button>
 *   </kendo-toolbar>
 * </kendo-grid>
 * ```
 * @remarks
 * Applied to: {@link ToolBarButtonComponent}.
 */
export declare class RemoveCommandToolbarDirective extends ToolbarEditingToolBase {
    editService: EditService;
    selection: SelectionService;
    constructor(editService: EditService, host: ToolBarButtonComponent, selection: SelectionService, ctx: ContextService, zone: NgZone, cdr: ChangeDetectorRef);
    /**
     * @hidden
     */
    onClick(e: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<RemoveCommandToolbarDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RemoveCommandToolbarDirective, "[kendoGridRemoveTool]", never, {}, {}, never, never, true, never>;
}
