/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2 as Renderer, NgZone, DoCheck } from '@angular/core';
import { Button } from '@progress/kendo-angular-buttons';
import { EditService } from './edit.service';
import { CellContext } from '../rendering/common/cell-context';
import { ContextService } from '../common/provider.service';
import * as i0 from "@angular/core";
/**
 * Represents the `remove` command of the Grid. Apply this directive to any `button` element
 * inside a [CommandColumnComponent]({% slug api_grid_commandcolumncomponent %})
 * ([see example](slug:editing_directives_grid#toc-command-column-directives)).
 * When you click the button with this directive, the
 * [`remove`]({% slug api_grid_gridcomponent %}#toc-remove) event fires.
 * The button with `kendoGridRemoveCommand` is automatically hidden when the row is in edit mode.
 *
 * @example
 * ```html
 * <kendo-grid>
 *   <kendo-grid-command-column title="command">
 *     <ng-template kendoGridCellTemplate>
 *       <button kendoGridRemoveCommand>Remove row</button>
 *     </ng-template>
 *   </kendo-grid-command-column>
 * </kendo-grid>
 * ```
 */
export declare class RemoveCommandDirective extends Button implements DoCheck {
    private editService;
    private cellContext;
    rowIndex: number;
    protected isEdited: boolean;
    /**
     * @hidden
     */
    get visible(): string;
    /**
     * @hidden
     */
    commandClass: boolean;
    /**
     * @hidden
     */
    onClick(e: any): void;
    constructor(editService: EditService, cellContext: CellContext, element: ElementRef, renderer: Renderer, ctx: ContextService, ngZone: NgZone);
    ngDoCheck(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<RemoveCommandDirective, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<RemoveCommandDirective, "[kendoGridRemoveCommand]", never, {}, {}, never, ["*"], true, never>;
}
