/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from '../common/preventable-event';
/**
 * Provides the arguments for the `columnReorder` event.
 */
export class ColumnReorderEvent extends PreventableEvent {
    /**
     * Represents the reordered column.
     */
    column;
    /**
     * Represents the new index of the column. This index is relative to the collection of columns.
     */
    newIndex;
    /**
     * Represents the original index of the column before reordering. This index is relative to the collection of columns.
     */
    oldIndex;
    /**
     * @hidden
     */
    constructor({ column, newIndex, oldIndex }) {
        super();
        this.column = column;
        this.newIndex = newIndex;
        this.oldIndex = oldIndex;
    }
}
