/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Directive, Input } from '@angular/core';
import { ComponentMessages } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export class GridMessages extends ComponentMessages {
    /**
     * Sets the text for the empty group panel.
     */
    groupPanelEmpty;
    /**
     * Sets the text when there are no records.
     */
    noRecords;
    /**
     * Sets the label for the pager. By default, it follows the pattern **Page {currentPage} of {totalPages}**.
     * For example, when the current page is 1 and the total number of pages is 10, the label is
     * **Page navigation, page 1 of 10**.
     *
     * The message includes the current page number, total number of pages, and a localizable string.
     * You can reorder these parts by using placeholders in the `pagerLabel` input.
     * Use `{currentPage}` and `{totalPages}` to insert the actual values.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    pagerLabel;
    /**
     * Sets the label for the **First page** button.
     */
    pagerFirstPage;
    /**
     * Sets the label for the **Last page** button.
     */
    pagerLastPage;
    /**
     * Sets the label for the **Previous page** button.
     */
    pagerPreviousPage;
    /**
     * Sets the label for the **Next page** button.
     */
    pagerNextPage;
    /**
     * Sets the text displayed before the pager input.
     */
    pagerPage;
    /**
     * Sets the text displayed after the page-size selector.
     */
    pagerItemsPerPage;
    /**
     * Sets the text displayed before the total-page number.
     */
    pagerOf;
    /**
     * Sets the text displayed after the total number of items.
     */
    pagerItems;
    /**
     * Sets the title attribute of the page number input element.
     */
    pagerPageNumberInputTitle;
    /**
     * Sets the text for the aria-label attribute on the page number input element.
     */
    pagerInputLabel;
    /**
     * Sets the text for the title and `aria-label` attributes on the page chooser in the Grid Pager.
     */
    pagerSelectPage;
    /**
     * Sets the label for the filter cell or icon.
     */
    filter;
    /**
     * Sets the label for the filter input.
     *
     * The filter input label includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default label is **Product Name Filter**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `filterInputLabel`.
     * Use `{columnName}` to insert the column name, for example, **filter for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    filterInputLabel;
    /**
     * Sets the title for the filter menu icon.
     *
     * The title includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default title is **Product Name Filter Menu**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `filterMenuTitle`.
     * Use `{columnName}` to insert the column name, for example, **filter for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    filterMenuTitle;
    /**
     * Sets the label for the filter menu operators DropDownList.
     *
     * The label includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default label is **Product Name Filter Menu Operators**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `filterMenuOperatorsDropDownLabel`.
     * Use `{columnName}` to insert the column name, for example, **filter operators for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    filterMenuOperatorsDropDownLabel;
    /**
     * Sets the label for the filter menu logic DropDownList.
     *
     * The label includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default label is **Product Name Filter Menu Logic**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `filterMenuLogicDropDownLabel`.
     * Use `{columnName}` to insert the column name, for example, **filter logic for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    filterMenuLogicDropDownLabel;
    /**
     * Sets the label for the filter cell operators DropDownList.
     *
     * The label includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default label is **Filter cell operators for Product Name**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `filterCellOperatorLabel`.
     * Use `{columnName}` to insert the column name, for example, **Filter operators for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    filterCellOperatorLabel;
    /**
     * Sets the label for the boolean filter cell DropDownList.
     *
     * The label includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default label is **Boolean filter cell for Product Name**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `booleanFilterCellLabel`.
     * Use `{columnName}` to insert the column name, for example, **Boolean Filter operator for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    booleanFilterCellLabel;
    /**
     * Sets the text for the `Equal` (**Is equal to**) filter operator.
     */
    filterEqOperator;
    /**
     * Sets the text for the `NotEqual` (**Is not equal to**) filter operator.
     */
    filterNotEqOperator;
    /**
     * Sets the text for the `IsNull` (**Is null**) filter operator.
     */
    filterIsNullOperator;
    /**
     * Sets the text for the `IsNotNull` (**Is not null**) filter operator.
     */
    filterIsNotNullOperator;
    /**
     * Sets the text for the `IsEmpty` (**Is empty**) filter operator.
     */
    filterIsEmptyOperator;
    /**
     * Sets the text for the `IsNotEmpty` (**Is not empty**) filter operator.
     */
    filterIsNotEmptyOperator;
    /**
     * Sets the text for the `StartsWith` (**Starts with**) filter operator.
     */
    filterStartsWithOperator;
    /**
     * Sets the text for the `Contains` (**Contains**) filter operator.
     */
    filterContainsOperator;
    /**
     * Sets the text for the `DoesNotContain` (**Does not contain**) filter operator.
     */
    filterNotContainsOperator;
    /**
     * Sets the text for the `EndsWith` (**Ends with**) string filter operator.
     */
    filterEndsWithOperator;
    /**
     * Sets the text for the `GreaterOrEqualTo` (**Is greater than or equal to**) numeric filter operator.
     */
    filterGteOperator;
    /**
     * Sets the text for the `Greater` (**Is greater than**) numeric filter operator.
     */
    filterGtOperator;
    /**
     * Sets the text for the `LessOrEqualTo` (**Is less than or equal to**) numeric filter operator.
     */
    filterLteOperator;
    /**
     * Sets the text for the `Less` (**Is less than**) numeric filter operator.
     */
    filterLtOperator;
    /**
     * Sets the text for the `IsTrue` Boolean filter option.
     */
    filterIsTrue;
    /**
     * Sets the text for the `IsFalse` Boolean filter option.
     */
    filterIsFalse;
    /**
     * Sets the text for the `(All)` option in the Boolean filter.
     */
    filterBooleanAll;
    /**
     * Sets the title for the Operators ActionSheet in adaptive mode.
     */
    adaptiveFilterOperatorsTitle;
    /**
     * Sets the text for the `AfterOrEqualTo` (**Is after or equal to**) date filter operator.
     */
    filterAfterOrEqualOperator;
    /**
     * Sets the text for the `After` (**Is after**) date filter operator.
     */
    filterAfterOperator;
    /**
     * Sets the text for the `Before` (**Is before**) date filter operator.
     */
    filterBeforeOperator;
    /**
     * Sets the text for the `BeforeOrEqualTo` (**Is before or equal to**) date filter operator.
     */
    filterBeforeOrEqualOperator;
    /**
     * Sets the text for the **Filter** button.
     */
    filterFilterButton;
    /**
     * Sets the text for the **Clear filter** button.
     */
    filterClearButton;
    /**
     * Sets the title for the **Close** button of the ActionSheet that appears instead of the Popup on small screens in adaptive mode.
     */
    adaptiveCloseButtonTitle;
    /**
     * Sets the title for the **Back** button of the ActionSheet that appears instead of the Popup on small screens in adaptive mode.
     */
    adaptiveBackButtonTitle;
    /**
     * Sets the text for the `And` filter logic.
     */
    filterAndLogic;
    /**
     * Sets the text for the `Or` filter logic.
     */
    filterOrLogic;
    /**
     * Sets the button text for the Filter toolbar tool.
     */
    filterToolbarToolText;
    /**
     * Sets the loading text. The `loading` property a Grid accessibility feature.
     * Screen readers can detect its value, but it is not visible otherwise.
     */
    loading;
    /**
     * Sets the text for the `aria-label` attribute on the Grid focusable element.
     */
    gridLabel;
    /**
     * Sets the title for the column menu icon.
     *
     * The title includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default title is **Product Name Column Menu**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `columnMenu`.
     * Use `{columnName}` to insert the column name, for example, **menu for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    columnMenu;
    /**
     * Sets the text in the column menu for the set column position item.
     */
    setColumnPosition;
    /**
     * Sets the text for the Grid Column Chooser and Column Chooser toolbar tool.
     */
    columns;
    /**
     * Sets the subtitle for the adaptive Grid Column Chooser and Column Chooser toolbar tool.
     */
    columnsSubtitle;
    /**
     * Sets the title for the adaptive Filter Toolbar Tool and Filter Menu.
     */
    adaptiveFilterTitle;
    /**
     * Sets the title for the adaptive Sort Toolbar Tool.
     */
    adaptiveSortTitle;
    /**
     * Sets the title for the adaptive Group Toolbar Tool.
     */
    adaptiveGroupTitle;
    /**
     * Sets the text for the **Clear all filters** button in the Filter Toolbar Tool and adaptive Filter Toolbar Tool.
     */
    filterClearAllButton;
    /**
     * Sets the text for the **Clear grouping** button in the Group Toolbar Tool and adaptive Group Toolbar Tool.
     */
    groupClearButton;
    /**
     * Sets the text for the clear sort button in the Sort Toolbar Tool and adaptive Sort Toolbar Tool.
     */
    sortClearButton;
    /**
     * Sets the text for the **Done** sort button.
     */
    sortDoneButton;
    /**
     * Sets the text for the **Done** group button in the adaptive Group Toolbar Tool.
     */
    groupDoneButton;
    /**
     * Sets the text in the column menu for the lock item.
     */
    lock;
    /**
     * Sets the text in the column menu for the unlock item.
     */
    unlock;
    /**
     * Sets the text in the column menu for the stick item.
     */
    stick;
    /**
     * Sets the text in the column menu for the unstick item.
     */
    unstick;
    /**
     * Sets the label for the sort icon.
     */
    sortable;
    /**
     * Sets the text in the column menu for the ascending sort item.
     */
    sortAscending;
    /**
     * Sets the text in the column menu for the descending sort item.
     */
    sortDescending;
    /**
     * Sets the text in the column menu for the autosize this column item.
     */
    autosizeThisColumn;
    /**
     * Sets the text in the column menu for the autosize all columns item.
     */
    autosizeAllColumns;
    /**
     * Sets the title of the Group Chip for ascending sorting order of groups.
     */
    sortedAscending;
    /**
     * Sets the title of the Group Chip for descending sorting order of groups.
     */
    sortedDescending;
    /**
     * Sets the status announcement when a column is no longer sorted.
     */
    sortedDefault;
    /**
     * Sets the button text for the Sort toolbar tool.
     */
    sortToolbarToolText;
    /**
     * Sets the text in the column menu or column chooser item for the **Apply** button.
     */
    columnsApply;
    /**
     * Sets the text in the column menu or column chooser item for the **Reset** button.
     */
    columnsReset;
    /**
     * Sets the title for the expand icon of detail rows.
     */
    detailExpand;
    /**
     * Sets the title for the collapse icon of detail rows.
     */
    detailCollapse;
    /**
     * Sets the text for the **Today** button in the Date filter.
     */
    filterDateToday;
    /**
     * Sets the title for the **Toggle** button in the Date filter.
     */
    filterDateToggle;
    /**
     * Sets the title for the **Decrement** button in the Numeric filter.
     */
    filterNumericDecrement;
    /**
     * Sets the title for the **Increment** button in the Numeric filter.
     */
    filterNumericIncrement;
    /**
     * Sets the labels of the checkboxes in the checkbox column.
     */
    selectionCheckboxLabel;
    /**
     * Sets the label for the select all checkbox in the checkbox column.
     */
    selectAllCheckboxLabel;
    /**
     * Sets the text for the title and `aria-label` attributes on the collapse icon of group rows.
     */
    groupCollapse;
    /**
     * Sets the text for the title and `aria-label` attributes on the expand icon of group rows.
     */
    groupExpand;
    /**
     * Sets the label for the top toolbar.
     */
    topToolbarLabel;
    /**
     * Sets the label for the bottom toolbar.
     */
    bottomToolbarLabel;
    /**
     * Sets the text for the Grid Edit toolbar tool.
     */
    editToolbarToolText;
    /**
     * Sets the text for the Grid Save toolbar tool.
     */
    saveToolbarToolText;
    /**
     * Sets the text for the Grid Add toolbar tool.
     */
    addToolbarToolText;
    /**
     * Sets the text for the Grid Cancel toolbar tool.
     */
    cancelToolbarToolText;
    /**
     * Sets the text for the Grid Remove toolbar tool.
     */
    removeToolbarToolText;
    /**
     * Sets the text for the Grid Excel Export toolbar tool.
     */
    excelExportToolbarToolText;
    /**
     * Sets the text for the Grid PDF Export toolbar tool.
     */
    pdfExportToolbarToolText;
    /**
     * Sets the label for the group panel toolbar.
     */
    groupPanelLabel;
    /**
     * Sets the label for the Grid drag row handle.
     */
    dragRowHandleLabel;
    /**
     * Sets the title for the column menu **Filter** tab.
     */
    columnMenuFilterTabTitle;
    /**
     * Sets the title for the column menu **General** tab.
     */
    columnMenuGeneralTabTitle;
    /**
     * Sets the title for the column menu **Columns** tab.
     */
    columnMenuColumnsTabTitle;
    /**
     * Sets the text for the Group pane Chip Menu **Move as previous** item.
     */
    groupChipMenuPrevious;
    /**
     * Sets the text for the Group pane Chip Menu **Move as next** item.
     */
    groupChipMenuNext;
    /**
     * Sets the button text for the Group toolbar tool.
     */
    groupToolbarToolText;
    /**
     * Sets the default text for a form validation error when you use built-in external editing.
     * <br/><br/>
     * The text includes the data item property name, the error name from the `FormControl` object, and a localizable string.
     * <br/><br/>
     * For a field named `ProductName` and an error named `required`, the default error text is `ProductName has required validation error`.
     * <br/><br/>
     * To customize the error text, use the `{errorName}` and `{fieldName}` placeholders and a custom localizable string.
     * For example, `{errorName} detected for {fieldName} field`.
     * <br/><br/>
     * The `{errorName}` and `{fieldName}` placeholders are replaced with the field and error names for the invalid form control,
     * and the error message is rendered as `required error detected for ProductName field`.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    formValidationErrorText;
    /**
     * Sets the title for the remove item confirmation Dialog.
     */
    removeConfirmationDialogTitle;
    /**
     * Sets the content for the remove item confirmation Dialog.
     */
    removeConfirmationDialogContent;
    /**
     * Sets the text for the confirm action button in the remove confirmation Dialog.
     */
    removeConfirmationDialogConfirmText;
    /**
     * Sets the text for the reject action button in the remove confirmation Dialog.
     */
    removeConfirmationDialogRejectText;
    /**
     * Sets the title for the external editing Dialog or ActionSheet when editing an item.
     */
    externalEditingTitle;
    /**
     * Sets the title for the external editing Dialog or ActionSheet when adding a new item.
     */
    externalEditingAddTitle;
    /**
     * Sets the text for the external editing Dialog <b>Save</b> button.
     */
    externalEditingSaveText;
    /**
     * Sets the text for the external editing Dialog <b>Cancel</b> button.
     */
    externalEditingCancelText;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridMessages, deps: null, target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: GridMessages, selector: "kendo-grid-messages-base", inputs: { groupPanelEmpty: "groupPanelEmpty", noRecords: "noRecords", pagerLabel: "pagerLabel", pagerFirstPage: "pagerFirstPage", pagerLastPage: "pagerLastPage", pagerPreviousPage: "pagerPreviousPage", pagerNextPage: "pagerNextPage", pagerPage: "pagerPage", pagerItemsPerPage: "pagerItemsPerPage", pagerOf: "pagerOf", pagerItems: "pagerItems", pagerPageNumberInputTitle: "pagerPageNumberInputTitle", pagerInputLabel: "pagerInputLabel", pagerSelectPage: "pagerSelectPage", filter: "filter", filterInputLabel: "filterInputLabel", filterMenuTitle: "filterMenuTitle", filterMenuOperatorsDropDownLabel: "filterMenuOperatorsDropDownLabel", filterMenuLogicDropDownLabel: "filterMenuLogicDropDownLabel", filterCellOperatorLabel: "filterCellOperatorLabel", booleanFilterCellLabel: "booleanFilterCellLabel", filterEqOperator: "filterEqOperator", filterNotEqOperator: "filterNotEqOperator", filterIsNullOperator: "filterIsNullOperator", filterIsNotNullOperator: "filterIsNotNullOperator", filterIsEmptyOperator: "filterIsEmptyOperator", filterIsNotEmptyOperator: "filterIsNotEmptyOperator", filterStartsWithOperator: "filterStartsWithOperator", filterContainsOperator: "filterContainsOperator", filterNotContainsOperator: "filterNotContainsOperator", filterEndsWithOperator: "filterEndsWithOperator", filterGteOperator: "filterGteOperator", filterGtOperator: "filterGtOperator", filterLteOperator: "filterLteOperator", filterLtOperator: "filterLtOperator", filterIsTrue: "filterIsTrue", filterIsFalse: "filterIsFalse", filterBooleanAll: "filterBooleanAll", adaptiveFilterOperatorsTitle: "adaptiveFilterOperatorsTitle", filterAfterOrEqualOperator: "filterAfterOrEqualOperator", filterAfterOperator: "filterAfterOperator", filterBeforeOperator: "filterBeforeOperator", filterBeforeOrEqualOperator: "filterBeforeOrEqualOperator", filterFilterButton: "filterFilterButton", filterClearButton: "filterClearButton", adaptiveCloseButtonTitle: "adaptiveCloseButtonTitle", adaptiveBackButtonTitle: "adaptiveBackButtonTitle", filterAndLogic: "filterAndLogic", filterOrLogic: "filterOrLogic", filterToolbarToolText: "filterToolbarToolText", loading: "loading", gridLabel: "gridLabel", columnMenu: "columnMenu", setColumnPosition: "setColumnPosition", columns: "columns", columnsSubtitle: "columnsSubtitle", adaptiveFilterTitle: "adaptiveFilterTitle", adaptiveSortTitle: "adaptiveSortTitle", adaptiveGroupTitle: "adaptiveGroupTitle", filterClearAllButton: "filterClearAllButton", groupClearButton: "groupClearButton", sortClearButton: "sortClearButton", sortDoneButton: "sortDoneButton", groupDoneButton: "groupDoneButton", lock: "lock", unlock: "unlock", stick: "stick", unstick: "unstick", sortable: "sortable", sortAscending: "sortAscending", sortDescending: "sortDescending", autosizeThisColumn: "autosizeThisColumn", autosizeAllColumns: "autosizeAllColumns", sortedAscending: "sortedAscending", sortedDescending: "sortedDescending", sortedDefault: "sortedDefault", sortToolbarToolText: "sortToolbarToolText", columnsApply: "columnsApply", columnsReset: "columnsReset", detailExpand: "detailExpand", detailCollapse: "detailCollapse", filterDateToday: "filterDateToday", filterDateToggle: "filterDateToggle", filterNumericDecrement: "filterNumericDecrement", filterNumericIncrement: "filterNumericIncrement", selectionCheckboxLabel: "selectionCheckboxLabel", selectAllCheckboxLabel: "selectAllCheckboxLabel", groupCollapse: "groupCollapse", groupExpand: "groupExpand", topToolbarLabel: "topToolbarLabel", bottomToolbarLabel: "bottomToolbarLabel", editToolbarToolText: "editToolbarToolText", saveToolbarToolText: "saveToolbarToolText", addToolbarToolText: "addToolbarToolText", cancelToolbarToolText: "cancelToolbarToolText", removeToolbarToolText: "removeToolbarToolText", excelExportToolbarToolText: "excelExportToolbarToolText", pdfExportToolbarToolText: "pdfExportToolbarToolText", groupPanelLabel: "groupPanelLabel", dragRowHandleLabel: "dragRowHandleLabel", columnMenuFilterTabTitle: "columnMenuFilterTabTitle", columnMenuGeneralTabTitle: "columnMenuGeneralTabTitle", columnMenuColumnsTabTitle: "columnMenuColumnsTabTitle", groupChipMenuPrevious: "groupChipMenuPrevious", groupChipMenuNext: "groupChipMenuNext", groupToolbarToolText: "groupToolbarToolText", formValidationErrorText: "formValidationErrorText", removeConfirmationDialogTitle: "removeConfirmationDialogTitle", removeConfirmationDialogContent: "removeConfirmationDialogContent", removeConfirmationDialogConfirmText: "removeConfirmationDialogConfirmText", removeConfirmationDialogRejectText: "removeConfirmationDialogRejectText", externalEditingTitle: "externalEditingTitle", externalEditingAddTitle: "externalEditingAddTitle", externalEditingSaveText: "externalEditingSaveText", externalEditingCancelText: "externalEditingCancelText" }, usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridMessages, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: 'kendo-grid-messages-base'
                }]
        }], propDecorators: { groupPanelEmpty: [{
                type: Input
            }], noRecords: [{
                type: Input
            }], pagerLabel: [{
                type: Input
            }], pagerFirstPage: [{
                type: Input
            }], pagerLastPage: [{
                type: Input
            }], pagerPreviousPage: [{
                type: Input
            }], pagerNextPage: [{
                type: Input
            }], pagerPage: [{
                type: Input
            }], pagerItemsPerPage: [{
                type: Input
            }], pagerOf: [{
                type: Input
            }], pagerItems: [{
                type: Input
            }], pagerPageNumberInputTitle: [{
                type: Input
            }], pagerInputLabel: [{
                type: Input
            }], pagerSelectPage: [{
                type: Input
            }], filter: [{
                type: Input
            }], filterInputLabel: [{
                type: Input
            }], filterMenuTitle: [{
                type: Input
            }], filterMenuOperatorsDropDownLabel: [{
                type: Input
            }], filterMenuLogicDropDownLabel: [{
                type: Input
            }], filterCellOperatorLabel: [{
                type: Input
            }], booleanFilterCellLabel: [{
                type: Input
            }], filterEqOperator: [{
                type: Input
            }], filterNotEqOperator: [{
                type: Input
            }], filterIsNullOperator: [{
                type: Input
            }], filterIsNotNullOperator: [{
                type: Input
            }], filterIsEmptyOperator: [{
                type: Input
            }], filterIsNotEmptyOperator: [{
                type: Input
            }], filterStartsWithOperator: [{
                type: Input
            }], filterContainsOperator: [{
                type: Input
            }], filterNotContainsOperator: [{
                type: Input
            }], filterEndsWithOperator: [{
                type: Input
            }], filterGteOperator: [{
                type: Input
            }], filterGtOperator: [{
                type: Input
            }], filterLteOperator: [{
                type: Input
            }], filterLtOperator: [{
                type: Input
            }], filterIsTrue: [{
                type: Input
            }], filterIsFalse: [{
                type: Input
            }], filterBooleanAll: [{
                type: Input
            }], adaptiveFilterOperatorsTitle: [{
                type: Input
            }], filterAfterOrEqualOperator: [{
                type: Input
            }], filterAfterOperator: [{
                type: Input
            }], filterBeforeOperator: [{
                type: Input
            }], filterBeforeOrEqualOperator: [{
                type: Input
            }], filterFilterButton: [{
                type: Input
            }], filterClearButton: [{
                type: Input
            }], adaptiveCloseButtonTitle: [{
                type: Input
            }], adaptiveBackButtonTitle: [{
                type: Input
            }], filterAndLogic: [{
                type: Input
            }], filterOrLogic: [{
                type: Input
            }], filterToolbarToolText: [{
                type: Input
            }], loading: [{
                type: Input
            }], gridLabel: [{
                type: Input
            }], columnMenu: [{
                type: Input
            }], setColumnPosition: [{
                type: Input
            }], columns: [{
                type: Input
            }], columnsSubtitle: [{
                type: Input
            }], adaptiveFilterTitle: [{
                type: Input
            }], adaptiveSortTitle: [{
                type: Input
            }], adaptiveGroupTitle: [{
                type: Input
            }], filterClearAllButton: [{
                type: Input
            }], groupClearButton: [{
                type: Input
            }], sortClearButton: [{
                type: Input
            }], sortDoneButton: [{
                type: Input
            }], groupDoneButton: [{
                type: Input
            }], lock: [{
                type: Input
            }], unlock: [{
                type: Input
            }], stick: [{
                type: Input
            }], unstick: [{
                type: Input
            }], sortable: [{
                type: Input
            }], sortAscending: [{
                type: Input
            }], sortDescending: [{
                type: Input
            }], autosizeThisColumn: [{
                type: Input
            }], autosizeAllColumns: [{
                type: Input
            }], sortedAscending: [{
                type: Input
            }], sortedDescending: [{
                type: Input
            }], sortedDefault: [{
                type: Input
            }], sortToolbarToolText: [{
                type: Input
            }], columnsApply: [{
                type: Input
            }], columnsReset: [{
                type: Input
            }], detailExpand: [{
                type: Input
            }], detailCollapse: [{
                type: Input
            }], filterDateToday: [{
                type: Input
            }], filterDateToggle: [{
                type: Input
            }], filterNumericDecrement: [{
                type: Input
            }], filterNumericIncrement: [{
                type: Input
            }], selectionCheckboxLabel: [{
                type: Input
            }], selectAllCheckboxLabel: [{
                type: Input
            }], groupCollapse: [{
                type: Input
            }], groupExpand: [{
                type: Input
            }], topToolbarLabel: [{
                type: Input
            }], bottomToolbarLabel: [{
                type: Input
            }], editToolbarToolText: [{
                type: Input
            }], saveToolbarToolText: [{
                type: Input
            }], addToolbarToolText: [{
                type: Input
            }], cancelToolbarToolText: [{
                type: Input
            }], removeToolbarToolText: [{
                type: Input
            }], excelExportToolbarToolText: [{
                type: Input
            }], pdfExportToolbarToolText: [{
                type: Input
            }], groupPanelLabel: [{
                type: Input
            }], dragRowHandleLabel: [{
                type: Input
            }], columnMenuFilterTabTitle: [{
                type: Input
            }], columnMenuGeneralTabTitle: [{
                type: Input
            }], columnMenuColumnsTabTitle: [{
                type: Input
            }], groupChipMenuPrevious: [{
                type: Input
            }], groupChipMenuNext: [{
                type: Input
            }], groupToolbarToolText: [{
                type: Input
            }], formValidationErrorText: [{
                type: Input
            }], removeConfirmationDialogTitle: [{
                type: Input
            }], removeConfirmationDialogContent: [{
                type: Input
            }], removeConfirmationDialogConfirmText: [{
                type: Input
            }], removeConfirmationDialogRejectText: [{
                type: Input
            }], externalEditingTitle: [{
                type: Input
            }], externalEditingAddTitle: [{
                type: Input
            }], externalEditingSaveText: [{
                type: Input
            }], externalEditingCancelText: [{
                type: Input
            }] } });
