/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnInit } from '@angular/core';
import { ColumnComponent } from '../columns/column.component';
import { FilterService } from './filter.service';
import { FilterDescriptor } from '@progress/kendo-data-query';
import { BaseFilterCellComponent } from './base-filter-cell.component';
import { FilterComponent } from './filter-component.interface';
import { CalendarView, DateInputFormatPlaceholder } from '@progress/kendo-angular-dateinputs';
import { ContextService } from '../common/provider.service';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class DateFilterComponent extends BaseFilterCellComponent implements FilterComponent, OnInit {
    protected ctx: ContextService;
    /**
     * Sets the column for this filter.
     * @type {ColumnComponent}
     */
    column: ColumnComponent;
    /**
     * Sets the default filter operator.
     * @type {string}
     * @default 'gte'
     */
    operator: string;
    /**
     * Gets the current filter for the column field.
     * @readonly
     * @type {FilterDescriptor}
     */
    get currentFilter(): FilterDescriptor;
    /**
     * Sets the date format used when the component is not focused.
     * Uses `column.format` if set.
     */
    set format(value: string);
    /**
     * Gets the date format used when the component is not focused.
     * Uses `column.format` if set.
     * @readonly
     * @type {string}
     */
    get format(): string;
    /**
     * Sets the smallest valid date value.
     * @type {Date}
     */
    min: Date;
    /**
     * Sets the largest valid date value.
     * @type {Date}
     */
    max: Date;
    /**
     * Sets the descriptions for the format sections in the input field.
     * [See example](slug:placeholders_datepicker#toc-format-sections-description).
     */
    formatPlaceholder: DateInputFormatPlaceholder;
    /**
     * Sets the hint shown when the value is `null`.
     * [See example](slug:placeholders_datepicker#toc-text-hints).
     */
    placeholder: string;
    /**
     * Sets the active calendar view when the calendar opens.
     * Set `activeView` within the `topView`-`bottomView` range.
     * @default 'month'
     */
    activeView: CalendarView;
    /**
     * Defines the lowest calendar view level the user can navigate to.
     * @default 'month'
     */
    bottomView: CalendarView;
    /**
     * Defines the highest calendar view level the user can navigate to.
     * @default 'century'
     */
    topView: CalendarView;
    /**
     * When `true`, shows a week number column in the `month` view.
     * @default false
     */
    weekNumber: boolean;
    /**
     * Gets the current filter operator for the column field.
     * @readonly
     * @type {string}
     */
    get currentOperator(): string;
    private get columnFormat();
    private _format;
    private subscription;
    constructor(filterService: FilterService, ctx: ContextService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    protected localizationChange(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DateFilterComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DateFilterComponent, "kendo-grid-date-filter-base", never, { "column": { "alias": "column"; "required": false; }; "operator": { "alias": "operator"; "required": false; }; "format": { "alias": "format"; "required": false; }; "min": { "alias": "min"; "required": false; }; "max": { "alias": "max"; "required": false; }; "formatPlaceholder": { "alias": "formatPlaceholder"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "activeView": { "alias": "activeView"; "required": false; }; "bottomView": { "alias": "bottomView"; "required": false; }; "topView": { "alias": "topView"; "required": false; }; "weekNumber": { "alias": "weekNumber"; "required": false; }; }, {}, never, never, false, never>;
}
