/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Configures the `filterable` option for the Grid.
 *
 * The possible values are:
 * * `row`&mdash;Shows a filter row in the Grid. [See example](slug:filter_row).
 * * `menu`&mdash;Shows a filter menu in the Grid. [See example](slug:filter_menu).
 * * `menu, row`&mdash;Shows both filter menu and filter row.
 *
 * @example
 * ```html
 * <kendo-grid filterable="menu, row"></kendo-grid>
 * ```
 */
export type FilterableSettings = boolean | 'row' | 'menu' | 'menu, row';
/**
 * @hidden
 */
export declare const isFilterable: (settings: FilterableSettings) => boolean;
/**
 * @hidden
 */
export declare const hasFilterMenu: (settings: FilterableSettings) => boolean;
/**
 * @hidden
 */
export declare const hasFilterRow: (settings: FilterableSettings) => boolean;
