/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { CompositeFilterDescriptor, FilterDescriptor } from '@progress/kendo-data-query';
import { FilterService } from '../filter.service';
import { NumericFilterComponent } from '../numeric-filter.component';
import { MenuTabbingService } from './menu-tabbing.service';
import { ContextService } from '../../common/provider.service';
import * as i0 from "@angular/core";
/**
 * Represents a numeric filter-menu component.
 * Use this component to filter numeric values in the Grid.
 *
 * @example
 * ```html
 * <kendo-grid-column field="UnitPrice">
 *   <ng-template kendoGridFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-grid-numeric-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *     </kendo-grid-numeric-filter-menu>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 * @remarks
 * Supported children components are: {@link EqualFilterOperatorComponent}, {@link NotEqualFilterOperatorComponent}, {@link GreaterFilterOperatorComponent}, {@link GreaterOrEqualToFilterOperatorComponent}, {@link LessFilterOperatorComponent}, {@link LessOrEqualToFilterOperatorComponent}, {@link IsNullFilterOperatorComponent}, {@link IsNotNullFilterOperatorComponent}.
 */
export declare class NumericFilterMenuComponent extends NumericFilterComponent {
    logicOperators: Array<{
        text: string;
        value: "and" | "or";
    }>;
    /**
     * @hidden
     */
    get hostClasses(): boolean;
    /**
     * Represents the current filter descriptor for the menu.
     * @type {CompositeFilterDescriptor}
     */
    filter: CompositeFilterDescriptor;
    /**
     * Determines if the inputs for the second criteria are displayed.
     * @default true
     */
    extra: boolean;
    /**
     * Represents the `FilterService` instance that handles changes in the filter descriptor.
     */
    filterService: FilterService;
    /**
     * Determines the delay in milliseconds before creating a filter descriptor based on the value.
     * A value of `0` means no delay.
     * @default 500
     */
    filterDelay: number;
    /**
     * The placeholder text for the filter input.
     * @type {string}
     */
    placeholder: string;
    /**
     * Sets the placeholder text for the extra filter input.
     * Applies when `extra` is set to `true`.
     * @type {string}
     */
    extraPlaceholder: string;
    /**
     * @hidden
     */
    menuTabbingService: MenuTabbingService;
    constructor(ctx: ContextService);
    get firstFilter(): FilterDescriptor;
    get secondFilter(): FilterDescriptor;
    logicChange(value: 'and' | 'or'): void;
    get filterMenuDropDownLabel(): string;
    protected localizationChange(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<NumericFilterMenuComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NumericFilterMenuComponent, "kendo-grid-numeric-filter-menu", never, { "filter": { "alias": "filter"; "required": false; }; "extra": { "alias": "extra"; "required": false; }; "filterService": { "alias": "filterService"; "required": false; }; "filterDelay": { "alias": "filterDelay"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "extraPlaceholder": { "alias": "extraPlaceholder"; "required": false; }; "menuTabbingService": { "alias": "menuTabbingService"; "required": false; }; }, {}, never, never, true, never>;
}
