/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { MenuTabbingService } from './menu-tabbing.service';
import { CompositeFilterDescriptor, FilterDescriptor } from '@progress/kendo-data-query';
import { StringFilterComponent } from '../string-filter.component';
import { FilterService } from '../filter.service';
import { ContextService } from '../../common/provider.service';
import * as i0 from "@angular/core";
/**
 * Represents a string-filter menu component.
 * Use this component to filter string values in the Grid.
 * [See example](slug:filter_menu#toc-built-in-filter-menu-components).
 *
 * @example
 * ```html
 * <kendo-grid-column field="ProductName">
 *   <ng-template kendoGridFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-grid-string-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *     </kendo-grid-string-filter-menu>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 * @remarks
 * Supported children components are: {@link EqualFilterOperatorComponent}, {@link NotEqualFilterOperatorComponent}, {@link ContainsFilterOperatorComponent}, {@link DoesNotContainFilterOperatorComponent}, {@link StartsWithFilterOperatorComponent}, {@link EndsWithFilterOperatorComponent}, {@link IsNullFilterOperatorComponent}, {@link IsNotNullFilterOperatorComponent}, {@link IsEmptyFilterOperatorComponent}, {@link IsNotEmptyFilterOperatorComponent}.
 */
export declare class StringFilterMenuComponent extends StringFilterComponent {
    ctx: ContextService;
    logicOperators: Array<{
        text: string;
        value: "and" | "or";
    }>;
    /**
     * @hidden
     */
    get hostClasses(): boolean;
    /**
     * The current menu filter.
     * @type {CompositeFilterDescriptor}
     */
    filter: CompositeFilterDescriptor;
    /**
     * Determines if the inputs for the second criteria are displayed.
     * @default true
     */
    extra: boolean;
    /**
     * Sets to `FilterService` instance that handles changes in the filter descriptor.
     */
    filterService: FilterService;
    /**
     * The placeholder text for the filter input.
     * @type {string}
     */
    placeholder: any;
    /**
     * Sets the placeholder text for the second filter input.
     * Applies when `extra` is set to `true`.
     * @type {string}
     */
    extraPlaceholder: any;
    /**
     * @hidden
     */
    menuTabbingService: MenuTabbingService;
    constructor(ctx: ContextService);
    get firstFilter(): FilterDescriptor;
    get secondFilter(): FilterDescriptor;
    logicChange(value: 'and' | 'or'): void;
    get filterMenuDropDownLabel(): string;
    protected localizationChange(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<StringFilterMenuComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<StringFilterMenuComponent, "kendo-grid-string-filter-menu", never, { "filter": { "alias": "filter"; "required": false; }; "extra": { "alias": "extra"; "required": false; }; "filterService": { "alias": "filterService"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "extraPlaceholder": { "alias": "extraPlaceholder"; "required": false; }; "menuTabbingService": { "alias": "menuTabbingService"; "required": false; }; }, {}, never, never, true, never>;
}
