/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnInit } from '@angular/core';
import { ColumnComponent } from '../columns/column.component';
import { FilterService } from './filter.service';
import { FilterDescriptor } from '@progress/kendo-data-query';
import { BaseFilterCellComponent } from './base-filter-cell.component';
import { FilterComponent } from './filter-component.interface';
import { ContextService } from '../common/provider.service';
import * as i0 from "@angular/core";
/**
 * @hidden
 * Represents a base numeric filter component.
 */
export declare abstract class NumericFilterComponent extends BaseFilterCellComponent implements FilterComponent, OnInit {
    protected ctx: ContextService;
    /**
     * Specifies the column for this filter.
     * @type {ColumnComponent}
     */
    column: ColumnComponent;
    /**
     * Sets the default filter operator.
     * @type {string}
     * @default 'eq'
     */
    operator: string;
    /**
     * Sets the value used to increment or decrement the component value.
     * @type {numeric}
     * @default 1
     */
    step: number;
    /**
     * Sets the smallest valid value.
     * @type {number}
     */
    min: number;
    /**
     * Sets the greatest valid value.
     * @type {number}
     */
    max: number;
    /**
     * When `true`, shows the **Up** and **Down** spin buttons.
     * @type {boolean}
     * @default true
     */
    spinners: boolean;
    /**
     * Sets the number precision for the value when focused.
     * If the user enters a number with greater precision, the value is rounded.
     * @type {number}
     */
    decimals: number;
    /**
     * Gets the number format used when the component is not focused.
     * Uses `column.format` if set.
     */
    get format(): string;
    set format(value: string);
    /**
     * Gets the current filter for the column field.
     * @readonly
     * @type {FilterDescriptor}
     */
    get currentFilter(): FilterDescriptor;
    /**
     * Gets the current filter operator for the column field.
     * @readonly
     * @type {string}
     */
    get currentOperator(): string;
    private get columnFormat();
    private _format;
    private subscription;
    constructor(filterService: FilterService, ctx: ContextService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    protected localizationChange(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<NumericFilterComponent, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NumericFilterComponent, never, never, { "column": { "alias": "column"; "required": false; }; "operator": { "alias": "operator"; "required": false; }; "step": { "alias": "step"; "required": false; }; "min": { "alias": "min"; "required": false; }; "max": { "alias": "max"; "required": false; }; "spinners": { "alias": "spinners"; "required": false; }; "decimals": { "alias": "decimals"; "required": false; }; "format": { "alias": "format"; "required": false; }; }, {}, never, never, false, never>;
}
