/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { FilterOperatorBase } from './filter-operator.base';
import { ContextService } from '../../common/provider.service';
import * as i0 from "@angular/core";
/**
 * Represents the `GreaterOrEqualTo` (**Is after or equal to**) [date filter](slug:filtering_grid#toc-date-filter) operator.
 * Use this operator to filter dates after or equal to the specified date.
 * [See example](slug:filter_row#toc-default-filter-operator).
 *
 * @example
 * ```html Filter Cell
 * <kendo-grid-column field="FirstOrderedOn">
 *   <ng-template kendoGridFilterCellTemplate let-filter let-column="column">
 *     <kendo-grid-date-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *       <kendo-filter-after-eq-operator></kendo-filter-after-eq-operator>
 *      </kendo-grid-date-filter-cell>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 * ```html Filter Menu
 * <kendo-grid-column field="FirstOrderedOn">
 *   <ng-template kendoGridFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-grid-date-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *       <kendo-filter-after-eq-operator></kendo-filter-after-eq-operator>
 *     </kendo-grid-date-filter-menu>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 */
export declare class AfterEqFilterOperatorComponent extends FilterOperatorBase {
    constructor(ctx: ContextService);
    /**
     * @hidden
     */
    toJSON(): {
        text: string;
        value: string;
    };
    static ɵfac: i0.ɵɵFactoryDeclaration<AfterEqFilterOperatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AfterEqFilterOperatorComponent, "kendo-filter-after-eq-operator", never, {}, {}, never, never, true, never>;
}
