/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ContextService } from '../../common/provider.service';
import { FilterOperatorBase } from './filter-operator.base';
import * as i0 from "@angular/core";
/**
 * Represents the `Equal` (**Is equal to**) filter operator. [See example](slug:filtering_grid#toc-using-the-built-in-directive).
 * Use this operator to filter values that are equal to the specified value.
 * For more information and examples, see the article on setting [default filter operators](slug:filter_row#toc-default-filter-operator).
 *
 * @example
 * ```html String Filter Cell
 * <kendo-grid-column field="ProductName" title="Product Name">
 *   <ng-template kendoGridFilterCellTemplate let-filter let-column="column">
 *     <kendo-grid-string-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *       <kendo-filter-eq-operator></kendo-filter-eq-operator>
 *     </kendo-grid-string-filter-cell>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 * ```html Numeric Filter Cell
 * <kendo-grid-column field="UnitPrice" title="Price">
 *   <ng-template kendoGridFilterCellTemplate let-filter let-column="column">
 *     <kendo-grid-numeric-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *       <kendo-filter-eq-operator></kendo-filter-eq-operator>
 *     </kendo-grid-numeric-filter-cell>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 * ```html Date Filter Cell
 * <kendo-grid-column field="FirstOrderedOn">
 *   <ng-template kendoGridFilterCellTemplate let-filter let-column="column">
 *     <kendo-grid-date-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *       <kendo-filter-eq-operator></kendo-filter-eq-operator>
 *      </kendo-grid-date-filter-cell>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 *
 * @example
 * ```html String Filter Menu
 * <kendo-grid-column field="ProductName" title="Product Name">
 *   <ng-template kendoGridFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-grid-string-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *       <kendo-filter-eq-operator></kendo-filter-eq-operator>
 *     </kendo-grid-string-filter-menu>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 * ```html Numeric Filter Menu
 * <kendo-grid-column field="UnitPrice" title="Price">
 *   <ng-template kendoGridFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-grid-numeric-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *       <kendo-filter-eq-operator></kendo-filter-eq-operator>
 *     </kendo-grid-numeric-filter-menu>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 * ```html Date Filter Menu
 * <kendo-grid-column field="FirstOrderedOn">
 *   <ng-template kendoGridFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-grid-date-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *       <kendo-filter-eq-operator></kendo-filter-eq-operator>
 *      </kendo-grid-date-filter-menu>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 */
export declare class EqualFilterOperatorComponent extends FilterOperatorBase {
    constructor(ctx: ContextService);
    static ɵfac: i0.ɵɵFactoryDeclaration<EqualFilterOperatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EqualFilterOperatorComponent, "kendo-filter-eq-operator", never, {}, {}, never, never, true, never>;
}
