/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ContextService } from '../../common/provider.service';
import { FilterOperatorBase } from './filter-operator.base';
import * as i0 from "@angular/core";
/**
 * Represents the `Greater` (**Is greater than**) [numeric filter](slug:filtering_grid#toc-numeric-filter) operator.
 * Use this operator to filter values greater than the specified number.
 * [See example](slug:filter_row#toc-default-filter-operator).
 *
 * @example
 * ```html Filter Cell
 * <kendo-grid-column field="UnitPrice" title="Price">
 *   <ng-template kendoGridFilterCellTemplate let-filter let-column="column">
 *     <kendo-grid-numeric-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *       <kendo-filter-gt-operator></kendo-filter-gt-operator>
 *     </kendo-grid-numeric-filter-cell>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 * ```html Filter Menu
 * <kendo-grid-column field="UnitPrice" title="Price">
 *   <ng-template kendoGridFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-grid-numeric-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *       <kendo-filter-gt-operator></kendo-filter-gt-operator>
 *     </kendo-grid-numeric-filter-menu>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 */
export declare class GreaterFilterOperatorComponent extends FilterOperatorBase {
    constructor(ctx: ContextService);
    static ɵfac: i0.ɵɵFactoryDeclaration<GreaterFilterOperatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GreaterFilterOperatorComponent, "kendo-filter-gt-operator", never, {}, {}, never, never, true, never>;
}
