/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * The directive allows customizing the content of the group header cell in the Grid.
 * Place an `<ng-template>` with the `kendoGridGroupHeaderTemplate` directive inside `<kendo-grid-column>` to set the group header template. ([See example](slug:grouping_grid_templates#toc-header-template)).
 *
 * The template context uses the current data item and provides these fields:
 * - `group`&mdash;The current group item.
 * - `field`&mdash;The field name used for grouping.
 * - `value`&mdash;The current group value.
 * - `aggregates`&mdash;All aggregate values for the current group.
 * - `index`&mdash;The index of the current group.
 * - `expanded`&mdash;A boolean that shows if the group is expanded.
 *
 * @example
 * ```html
 * <kendo-grid [data]="gridData" [group]="groups">
 *    <kendo-grid-column field="ProductName">
 *       <ng-template kendoGridGroupHeaderTemplate let-group let-field="field" let-value="value">
 *          <strong>{{field}}</strong>: {{value}}
 *       </ng-template>
 *    </kendo-grid-column>
 * </kendo-grid>
 * ```
 */
export declare class GroupHeaderTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<GroupHeaderTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<GroupHeaderTemplateDirective, "[kendoGridGroupHeaderTemplate]", never, {}, {}, never, never, true, never>;
}
