/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Shows the default format for the [`kendoGridExpandGroupBy`]({% slug api_grid_expandgroupdirective %}) directive.
 * The directive saves the expanded group keys. ([See example]({% slug groups_expanded_state_grid %}#toc-built-in-directive)).
 *
 * The Grid checks if a group is expanded or collapsed by comparing all of these field values.
 */
export interface GroupKey {
    /**
     * Specifies the `field` property value of the current group item.
     */
    field: string;
    /**
     * Specifies the `value` property value of the current group item.
     */
    value: any;
    /**
     * Represents an array of `{ field: string, value: any }` items that lists all parent groups of the current group.
     * The array starts from the direct parent group and goes up to the root group. [See example](slug:groups_expanded_state_grid#toc-default-configuration).
     *
     */
    parentGroupKeys?: Array<{
        field: string;
        value: any;
    }>;
}
