/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ComponentMessages } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class GridMessages extends ComponentMessages {
    /**
     * Sets the text for the empty group panel.
     */
    groupPanelEmpty: string;
    /**
     * Sets the text when there are no records.
     */
    noRecords: string;
    /**
     * Sets the label for the pager. By default, it follows the pattern **Page {currentPage} of {totalPages}**.
     * For example, when the current page is 1 and the total number of pages is 10, the label is
     * **Page navigation, page 1 of 10**.
     *
     * The message includes the current page number, total number of pages, and a localizable string.
     * You can reorder these parts by using placeholders in the `pagerLabel` input.
     * Use `{currentPage}` and `{totalPages}` to insert the actual values.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    pagerLabel: string;
    /**
     * Sets the label for the **First page** button.
     */
    pagerFirstPage: string;
    /**
     * Sets the label for the **Last page** button.
     */
    pagerLastPage: string;
    /**
     * Sets the label for the **Previous page** button.
     */
    pagerPreviousPage: string;
    /**
     * Sets the label for the **Next page** button.
     */
    pagerNextPage: string;
    /**
     * Sets the text displayed before the pager input.
     */
    pagerPage: string;
    /**
     * Sets the text displayed after the page-size selector.
     */
    pagerItemsPerPage: string;
    /**
     * Sets the text displayed before the total-page number.
     */
    pagerOf: string;
    /**
     * Sets the text displayed after the total number of items.
     */
    pagerItems: string;
    /**
     * Sets the title attribute of the page number input element.
     */
    pagerPageNumberInputTitle: string;
    /**
     * Sets the text for the aria-label attribute on the page number input element.
     */
    pagerInputLabel: string;
    /**
     * Sets the text for the title and `aria-label` attributes on the page chooser in the Grid Pager.
     */
    pagerSelectPage: string;
    /**
     * Sets the label for the filter cell or icon.
     */
    filter: string;
    /**
     * Sets the label for the filter input.
     *
     * The filter input label includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default label is **Product Name Filter**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `filterInputLabel`.
     * Use `{columnName}` to insert the column name, for example, **filter for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    filterInputLabel: string;
    /**
     * Sets the title for the filter menu icon.
     *
     * The title includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default title is **Product Name Filter Menu**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `filterMenuTitle`.
     * Use `{columnName}` to insert the column name, for example, **filter for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    filterMenuTitle: string;
    /**
     * Sets the label for the filter menu operators DropDownList.
     *
     * The label includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default label is **Product Name Filter Menu Operators**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `filterMenuOperatorsDropDownLabel`.
     * Use `{columnName}` to insert the column name, for example, **filter operators for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    filterMenuOperatorsDropDownLabel: string;
    /**
     * Sets the label for the filter menu logic DropDownList.
     *
     * The label includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default label is **Product Name Filter Menu Logic**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `filterMenuLogicDropDownLabel`.
     * Use `{columnName}` to insert the column name, for example, **filter logic for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    filterMenuLogicDropDownLabel: string;
    /**
     * Sets the label for the filter cell operators DropDownList.
     *
     * The label includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default label is **Filter cell operators for Product Name**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `filterCellOperatorLabel`.
     * Use `{columnName}` to insert the column name, for example, **Filter operators for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    filterCellOperatorLabel: string;
    /**
     * Sets the label for the boolean filter cell DropDownList.
     *
     * The label includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default label is **Boolean filter cell for Product Name**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `booleanFilterCellLabel`.
     * Use `{columnName}` to insert the column name, for example, **Boolean Filter operator for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    booleanFilterCellLabel: string;
    /**
     * Sets the text for the `Equal` (**Is equal to**) filter operator.
     */
    filterEqOperator: string;
    /**
     * Sets the text for the `NotEqual` (**Is not equal to**) filter operator.
     */
    filterNotEqOperator: string;
    /**
     * Sets the text for the `IsNull` (**Is null**) filter operator.
     */
    filterIsNullOperator: string;
    /**
     * Sets the text for the `IsNotNull` (**Is not null**) filter operator.
     */
    filterIsNotNullOperator: string;
    /**
     * Sets the text for the `IsEmpty` (**Is empty**) filter operator.
     */
    filterIsEmptyOperator: string;
    /**
     * Sets the text for the `IsNotEmpty` (**Is not empty**) filter operator.
     */
    filterIsNotEmptyOperator: string;
    /**
     * Sets the text for the `StartsWith` (**Starts with**) filter operator.
     */
    filterStartsWithOperator: string;
    /**
     * Sets the text for the `Contains` (**Contains**) filter operator.
     */
    filterContainsOperator: string;
    /**
     * Sets the text for the `DoesNotContain` (**Does not contain**) filter operator.
     */
    filterNotContainsOperator: string;
    /**
     * Sets the text for the `EndsWith` (**Ends with**) string filter operator.
     */
    filterEndsWithOperator: string;
    /**
     * Sets the text for the `GreaterOrEqualTo` (**Is greater than or equal to**) numeric filter operator.
     */
    filterGteOperator: string;
    /**
     * Sets the text for the `Greater` (**Is greater than**) numeric filter operator.
     */
    filterGtOperator: string;
    /**
     * Sets the text for the `LessOrEqualTo` (**Is less than or equal to**) numeric filter operator.
     */
    filterLteOperator: string;
    /**
     * Sets the text for the `Less` (**Is less than**) numeric filter operator.
     */
    filterLtOperator: string;
    /**
     * Sets the text for the `IsTrue` Boolean filter option.
     */
    filterIsTrue: string;
    /**
     * Sets the text for the `IsFalse` Boolean filter option.
     */
    filterIsFalse: string;
    /**
     * Sets the text for the `(All)` option in the Boolean filter.
     */
    filterBooleanAll: string;
    /**
     * Sets the title for the Operators ActionSheet in adaptive mode.
     */
    adaptiveFilterOperatorsTitle: any;
    /**
     * Sets the text for the `AfterOrEqualTo` (**Is after or equal to**) date filter operator.
     */
    filterAfterOrEqualOperator: string;
    /**
     * Sets the text for the `After` (**Is after**) date filter operator.
     */
    filterAfterOperator: string;
    /**
     * Sets the text for the `Before` (**Is before**) date filter operator.
     */
    filterBeforeOperator: string;
    /**
     * Sets the text for the `BeforeOrEqualTo` (**Is before or equal to**) date filter operator.
     */
    filterBeforeOrEqualOperator: string;
    /**
     * Sets the text for the **Filter** button.
     */
    filterFilterButton: string;
    /**
     * Sets the text for the **Clear filter** button.
     */
    filterClearButton: string;
    /**
     * Sets the title for the **Close** button of the ActionSheet that appears instead of the Popup on small screens in adaptive mode.
     */
    adaptiveCloseButtonTitle: string;
    /**
     * Sets the title for the **Back** button of the ActionSheet that appears instead of the Popup on small screens in adaptive mode.
     */
    adaptiveBackButtonTitle: string;
    /**
     * Sets the text for the `And` filter logic.
     */
    filterAndLogic: string;
    /**
     * Sets the text for the `Or` filter logic.
     */
    filterOrLogic: string;
    /**
     * Sets the button text for the Filter toolbar tool.
     */
    filterToolbarToolText: string;
    /**
     * Sets the loading text. The `loading` property a Grid accessibility feature.
     * Screen readers can detect its value, but it is not visible otherwise.
     */
    loading: string;
    /**
     * Sets the text for the `aria-label` attribute on the Grid focusable element.
     */
    gridLabel: string;
    /**
     * Sets the title for the column menu icon.
     *
     * The title includes the column name and a localizable string.
     * For example, for a column named **Product Name**, the default title is **Product Name Column Menu**.
     *
     * You can reorder the column name and the localizable part by using a placeholder in `columnMenu`.
     * Use `{columnName}` to insert the column name, for example, **menu for {columnName}**.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    columnMenu: string;
    /**
     * Sets the text in the column menu for the set column position item.
     */
    setColumnPosition: string;
    /**
     * Sets the text for the Grid Column Chooser and Column Chooser toolbar tool.
     */
    columns: string;
    /**
     * Sets the subtitle for the adaptive Grid Column Chooser and Column Chooser toolbar tool.
     */
    columnsSubtitle: string;
    /**
     * Sets the title for the adaptive Filter Toolbar Tool and Filter Menu.
     */
    adaptiveFilterTitle: string;
    /**
     * Sets the title for the adaptive Sort Toolbar Tool.
     */
    adaptiveSortTitle: string;
    /**
     * Sets the title for the adaptive Group Toolbar Tool.
     */
    adaptiveGroupTitle: string;
    /**
     * Sets the text for the **Clear all filters** button in the Filter Toolbar Tool and adaptive Filter Toolbar Tool.
     */
    filterClearAllButton: string;
    /**
     * Sets the text for the **Clear grouping** button in the Group Toolbar Tool and adaptive Group Toolbar Tool.
     */
    groupClearButton: string;
    /**
     * Sets the text for the clear sort button in the Sort Toolbar Tool and adaptive Sort Toolbar Tool.
     */
    sortClearButton: string;
    /**
     * Sets the text for the **Done** sort button.
     */
    sortDoneButton: string;
    /**
     * Sets the text for the **Done** group button in the adaptive Group Toolbar Tool.
     */
    groupDoneButton: string;
    /**
     * Sets the text in the column menu for the lock item.
     */
    lock: string;
    /**
     * Sets the text in the column menu for the unlock item.
     */
    unlock: string;
    /**
     * Sets the text in the column menu for the stick item.
     */
    stick: string;
    /**
     * Sets the text in the column menu for the unstick item.
     */
    unstick: string;
    /**
     * Sets the label for the sort icon.
     */
    sortable: string;
    /**
     * Sets the text in the column menu for the ascending sort item.
     */
    sortAscending: string;
    /**
     * Sets the text in the column menu for the descending sort item.
     */
    sortDescending: string;
    /**
     * Sets the text in the column menu for the autosize this column item.
     */
    autosizeThisColumn: string;
    /**
     * Sets the text in the column menu for the autosize all columns item.
     */
    autosizeAllColumns: string;
    /**
     * Sets the title of the Group Chip for ascending sorting order of groups.
     */
    sortedAscending: string;
    /**
     * Sets the title of the Group Chip for descending sorting order of groups.
     */
    sortedDescending: string;
    /**
     * Sets the status announcement when a column is no longer sorted.
     */
    sortedDefault: string;
    /**
     * Sets the button text for the Sort toolbar tool.
     */
    sortToolbarToolText: string;
    /**
     * Sets the text in the column menu or column chooser item for the **Apply** button.
     */
    columnsApply: string;
    /**
     * Sets the text in the column menu or column chooser item for the **Reset** button.
     */
    columnsReset: string;
    /**
     * Sets the title for the expand icon of detail rows.
     */
    detailExpand: string;
    /**
     * Sets the title for the collapse icon of detail rows.
     */
    detailCollapse: string;
    /**
     * Sets the text for the **Today** button in the Date filter.
     */
    filterDateToday: string;
    /**
     * Sets the title for the **Toggle** button in the Date filter.
     */
    filterDateToggle: string;
    /**
     * Sets the title for the **Decrement** button in the Numeric filter.
     */
    filterNumericDecrement: string;
    /**
     * Sets the title for the **Increment** button in the Numeric filter.
     */
    filterNumericIncrement: string;
    /**
     * Sets the labels of the checkboxes in the checkbox column.
     */
    selectionCheckboxLabel: string;
    /**
     * Sets the label for the select all checkbox in the checkbox column.
     */
    selectAllCheckboxLabel: string;
    /**
     * Sets the text for the title and `aria-label` attributes on the collapse icon of group rows.
     */
    groupCollapse: string;
    /**
     * Sets the text for the title and `aria-label` attributes on the expand icon of group rows.
     */
    groupExpand: string;
    /**
     * Sets the label for the top toolbar.
     */
    topToolbarLabel: string;
    /**
     * Sets the label for the bottom toolbar.
     */
    bottomToolbarLabel: string;
    /**
     * Sets the text for the Grid Edit toolbar tool.
     */
    editToolbarToolText: string;
    /**
     * Sets the text for the Grid Save toolbar tool.
     */
    saveToolbarToolText: string;
    /**
     * Sets the text for the Grid Add toolbar tool.
     */
    addToolbarToolText: string;
    /**
     * Sets the text for the Grid Cancel toolbar tool.
     */
    cancelToolbarToolText: string;
    /**
     * Sets the text for the Grid Remove toolbar tool.
     */
    removeToolbarToolText: string;
    /**
     * Sets the text for the Grid Excel Export toolbar tool.
     */
    excelExportToolbarToolText: string;
    /**
     * Sets the text for the Grid PDF Export toolbar tool.
     */
    pdfExportToolbarToolText: string;
    /**
     * Sets the label for the group panel toolbar.
     */
    groupPanelLabel: string;
    /**
     * Sets the label for the Grid drag row handle.
     */
    dragRowHandleLabel: string;
    /**
     * Sets the title for the column menu **Filter** tab.
     */
    columnMenuFilterTabTitle: string;
    /**
     * Sets the title for the column menu **General** tab.
     */
    columnMenuGeneralTabTitle: string;
    /**
     * Sets the title for the column menu **Columns** tab.
     */
    columnMenuColumnsTabTitle: string;
    /**
     * Sets the text for the Group pane Chip Menu **Move as previous** item.
     */
    groupChipMenuPrevious: string;
    /**
     * Sets the text for the Group pane Chip Menu **Move as next** item.
     */
    groupChipMenuNext: string;
    /**
     * Sets the button text for the Group toolbar tool.
     */
    groupToolbarToolText: string;
    /**
     * Sets the default text for a form validation error when you use built-in external editing.
     * <br/><br/>
     * The text includes the data item property name, the error name from the `FormControl` object, and a localizable string.
     * <br/><br/>
     * For a field named `ProductName` and an error named `required`, the default error text is `ProductName has required validation error`.
     * <br/><br/>
     * To customize the error text, use the `{errorName}` and `{fieldName}` placeholders and a custom localizable string.
     * For example, `{errorName} detected for {fieldName} field`.
     * <br/><br/>
     * The `{errorName}` and `{fieldName}` placeholders are replaced with the field and error names for the invalid form control,
     * and the error message is rendered as `required error detected for ProductName field`.
     * [See example](slug:globalization_grid#toc-custom-messages).
     */
    formValidationErrorText: string;
    /**
     * Sets the title for the remove item confirmation Dialog.
     */
    removeConfirmationDialogTitle: string;
    /**
     * Sets the content for the remove item confirmation Dialog.
     */
    removeConfirmationDialogContent: string;
    /**
     * Sets the text for the confirm action button in the remove confirmation Dialog.
     */
    removeConfirmationDialogConfirmText: string;
    /**
     * Sets the text for the reject action button in the remove confirmation Dialog.
     */
    removeConfirmationDialogRejectText: string;
    /**
     * Sets the title for the external editing Dialog or ActionSheet when editing an item.
     */
    externalEditingTitle: string;
    /**
     * Sets the title for the external editing Dialog or ActionSheet when adding a new item.
     */
    externalEditingAddTitle: string;
    /**
     * Sets the text for the external editing Dialog <b>Save</b> button.
     */
    externalEditingSaveText: string;
    /**
     * Sets the text for the external editing Dialog <b>Cancel</b> button.
     */
    externalEditingCancelText: string;
    static ɵfac: i0.ɵɵFactoryDeclaration<GridMessages, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<GridMessages, "kendo-grid-messages-base", never, { "groupPanelEmpty": { "alias": "groupPanelEmpty"; "required": false; }; "noRecords": { "alias": "noRecords"; "required": false; }; "pagerLabel": { "alias": "pagerLabel"; "required": false; }; "pagerFirstPage": { "alias": "pagerFirstPage"; "required": false; }; "pagerLastPage": { "alias": "pagerLastPage"; "required": false; }; "pagerPreviousPage": { "alias": "pagerPreviousPage"; "required": false; }; "pagerNextPage": { "alias": "pagerNextPage"; "required": false; }; "pagerPage": { "alias": "pagerPage"; "required": false; }; "pagerItemsPerPage": { "alias": "pagerItemsPerPage"; "required": false; }; "pagerOf": { "alias": "pagerOf"; "required": false; }; "pagerItems": { "alias": "pagerItems"; "required": false; }; "pagerPageNumberInputTitle": { "alias": "pagerPageNumberInputTitle"; "required": false; }; "pagerInputLabel": { "alias": "pagerInputLabel"; "required": false; }; "pagerSelectPage": { "alias": "pagerSelectPage"; "required": false; }; "filter": { "alias": "filter"; "required": false; }; "filterInputLabel": { "alias": "filterInputLabel"; "required": false; }; "filterMenuTitle": { "alias": "filterMenuTitle"; "required": false; }; "filterMenuOperatorsDropDownLabel": { "alias": "filterMenuOperatorsDropDownLabel"; "required": false; }; "filterMenuLogicDropDownLabel": { "alias": "filterMenuLogicDropDownLabel"; "required": false; }; "filterCellOperatorLabel": { "alias": "filterCellOperatorLabel"; "required": false; }; "booleanFilterCellLabel": { "alias": "booleanFilterCellLabel"; "required": false; }; "filterEqOperator": { "alias": "filterEqOperator"; "required": false; }; "filterNotEqOperator": { "alias": "filterNotEqOperator"; "required": false; }; "filterIsNullOperator": { "alias": "filterIsNullOperator"; "required": false; }; "filterIsNotNullOperator": { "alias": "filterIsNotNullOperator"; "required": false; }; "filterIsEmptyOperator": { "alias": "filterIsEmptyOperator"; "required": false; }; "filterIsNotEmptyOperator": { "alias": "filterIsNotEmptyOperator"; "required": false; }; "filterStartsWithOperator": { "alias": "filterStartsWithOperator"; "required": false; }; "filterContainsOperator": { "alias": "filterContainsOperator"; "required": false; }; "filterNotContainsOperator": { "alias": "filterNotContainsOperator"; "required": false; }; "filterEndsWithOperator": { "alias": "filterEndsWithOperator"; "required": false; }; "filterGteOperator": { "alias": "filterGteOperator"; "required": false; }; "filterGtOperator": { "alias": "filterGtOperator"; "required": false; }; "filterLteOperator": { "alias": "filterLteOperator"; "required": false; }; "filterLtOperator": { "alias": "filterLtOperator"; "required": false; }; "filterIsTrue": { "alias": "filterIsTrue"; "required": false; }; "filterIsFalse": { "alias": "filterIsFalse"; "required": false; }; "filterBooleanAll": { "alias": "filterBooleanAll"; "required": false; }; "adaptiveFilterOperatorsTitle": { "alias": "adaptiveFilterOperatorsTitle"; "required": false; }; "filterAfterOrEqualOperator": { "alias": "filterAfterOrEqualOperator"; "required": false; }; "filterAfterOperator": { "alias": "filterAfterOperator"; "required": false; }; "filterBeforeOperator": { "alias": "filterBeforeOperator"; "required": false; }; "filterBeforeOrEqualOperator": { "alias": "filterBeforeOrEqualOperator"; "required": false; }; "filterFilterButton": { "alias": "filterFilterButton"; "required": false; }; "filterClearButton": { "alias": "filterClearButton"; "required": false; }; "adaptiveCloseButtonTitle": { "alias": "adaptiveCloseButtonTitle"; "required": false; }; "adaptiveBackButtonTitle": { "alias": "adaptiveBackButtonTitle"; "required": false; }; "filterAndLogic": { "alias": "filterAndLogic"; "required": false; }; "filterOrLogic": { "alias": "filterOrLogic"; "required": false; }; "filterToolbarToolText": { "alias": "filterToolbarToolText"; "required": false; }; "loading": { "alias": "loading"; "required": false; }; "gridLabel": { "alias": "gridLabel"; "required": false; }; "columnMenu": { "alias": "columnMenu"; "required": false; }; "setColumnPosition": { "alias": "setColumnPosition"; "required": false; }; "columns": { "alias": "columns"; "required": false; }; "columnsSubtitle": { "alias": "columnsSubtitle"; "required": false; }; "adaptiveFilterTitle": { "alias": "adaptiveFilterTitle"; "required": false; }; "adaptiveSortTitle": { "alias": "adaptiveSortTitle"; "required": false; }; "adaptiveGroupTitle": { "alias": "adaptiveGroupTitle"; "required": false; }; "filterClearAllButton": { "alias": "filterClearAllButton"; "required": false; }; "groupClearButton": { "alias": "groupClearButton"; "required": false; }; "sortClearButton": { "alias": "sortClearButton"; "required": false; }; "sortDoneButton": { "alias": "sortDoneButton"; "required": false; }; "groupDoneButton": { "alias": "groupDoneButton"; "required": false; }; "lock": { "alias": "lock"; "required": false; }; "unlock": { "alias": "unlock"; "required": false; }; "stick": { "alias": "stick"; "required": false; }; "unstick": { "alias": "unstick"; "required": false; }; "sortable": { "alias": "sortable"; "required": false; }; "sortAscending": { "alias": "sortAscending"; "required": false; }; "sortDescending": { "alias": "sortDescending"; "required": false; }; "autosizeThisColumn": { "alias": "autosizeThisColumn"; "required": false; }; "autosizeAllColumns": { "alias": "autosizeAllColumns"; "required": false; }; "sortedAscending": { "alias": "sortedAscending"; "required": false; }; "sortedDescending": { "alias": "sortedDescending"; "required": false; }; "sortedDefault": { "alias": "sortedDefault"; "required": false; }; "sortToolbarToolText": { "alias": "sortToolbarToolText"; "required": false; }; "columnsApply": { "alias": "columnsApply"; "required": false; }; "columnsReset": { "alias": "columnsReset"; "required": false; }; "detailExpand": { "alias": "detailExpand"; "required": false; }; "detailCollapse": { "alias": "detailCollapse"; "required": false; }; "filterDateToday": { "alias": "filterDateToday"; "required": false; }; "filterDateToggle": { "alias": "filterDateToggle"; "required": false; }; "filterNumericDecrement": { "alias": "filterNumericDecrement"; "required": false; }; "filterNumericIncrement": { "alias": "filterNumericIncrement"; "required": false; }; "selectionCheckboxLabel": { "alias": "selectionCheckboxLabel"; "required": false; }; "selectAllCheckboxLabel": { "alias": "selectAllCheckboxLabel"; "required": false; }; "groupCollapse": { "alias": "groupCollapse"; "required": false; }; "groupExpand": { "alias": "groupExpand"; "required": false; }; "topToolbarLabel": { "alias": "topToolbarLabel"; "required": false; }; "bottomToolbarLabel": { "alias": "bottomToolbarLabel"; "required": false; }; "editToolbarToolText": { "alias": "editToolbarToolText"; "required": false; }; "saveToolbarToolText": { "alias": "saveToolbarToolText"; "required": false; }; "addToolbarToolText": { "alias": "addToolbarToolText"; "required": false; }; "cancelToolbarToolText": { "alias": "cancelToolbarToolText"; "required": false; }; "removeToolbarToolText": { "alias": "removeToolbarToolText"; "required": false; }; "excelExportToolbarToolText": { "alias": "excelExportToolbarToolText"; "required": false; }; "pdfExportToolbarToolText": { "alias": "pdfExportToolbarToolText"; "required": false; }; "groupPanelLabel": { "alias": "groupPanelLabel"; "required": false; }; "dragRowHandleLabel": { "alias": "dragRowHandleLabel"; "required": false; }; "columnMenuFilterTabTitle": { "alias": "columnMenuFilterTabTitle"; "required": false; }; "columnMenuGeneralTabTitle": { "alias": "columnMenuGeneralTabTitle"; "required": false; }; "columnMenuColumnsTabTitle": { "alias": "columnMenuColumnsTabTitle"; "required": false; }; "groupChipMenuPrevious": { "alias": "groupChipMenuPrevious"; "required": false; }; "groupChipMenuNext": { "alias": "groupChipMenuNext"; "required": false; }; "groupToolbarToolText": { "alias": "groupToolbarToolText"; "required": false; }; "formValidationErrorText": { "alias": "formValidationErrorText"; "required": false; }; "removeConfirmationDialogTitle": { "alias": "removeConfirmationDialogTitle"; "required": false; }; "removeConfirmationDialogContent": { "alias": "removeConfirmationDialogContent"; "required": false; }; "removeConfirmationDialogConfirmText": { "alias": "removeConfirmationDialogConfirmText"; "required": false; }; "removeConfirmationDialogRejectText": { "alias": "removeConfirmationDialogRejectText"; "required": false; }; "externalEditingTitle": { "alias": "externalEditingTitle"; "required": false; }; "externalEditingAddTitle": { "alias": "externalEditingAddTitle"; "required": false; }; "externalEditingSaveText": { "alias": "externalEditingSaveText"; "required": false; }; "externalEditingCancelText": { "alias": "externalEditingCancelText"; "required": false; }; }, {}, never, never, false, never>;
}
