/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { FocusGroup } from './focus-group';
/**
 * Represents the metadata for a focusable Grid cell.
 * Focusable Grid cells include headers, group headers and footers, and data cells.
 */
export interface NavigationCell {
    /**
     * @hidden
     */
    uid: number;
    /**
     * Specifies the column index of the cell.
     */
    colIndex: number;
    /**
     * Specifies the logical index of the row that contains this cell. The row index is absolute and does not change with paging.
     * Group headers and footers are included. Header rows start at index `0`.
     */
    rowIndex: number;
    /**
     * Sets the column span for this cell, if defined.
     */
    colSpan?: number;
    /**
     * Sets the row span for this cell, if defined.
     */
    rowSpan?: number;
    /**
     * Specifies the data item index for the parent row of this cell.
     */
    dataRowIndex: number;
    /**
     * Provides the data item for the parent row of this cell.
     */
    dataItem: any;
    /**
     * @hidden
     */
    parent?: NavigationCell;
    /**
     * @hidden
     */
    focusGroup?: FocusGroup;
    /**
     * @hidden
     */
    detailExpandCell?: boolean;
}
