/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NavigationCell } from './navigation-cell.interface';
import { GroupItem } from '../data/group-item.interface';
/**
 * Represents the metadata for a focusable Grid row. Focusable rows include headers, group headers and footers, and data rows.
 */
export interface NavigationRow {
    /**
     * @hidden
     */
    uid: number;
    /**
     * Specifies the logical index of the focusable row. The row index is absolute and does not change with paging.
     * Group headers and footers are included. Header rows start at index 0.
     */
    index: number;
    /**
     * Specifies the data item index for this row.
     */
    dataRowIndex: number;
    /**
     * Provides the data item for this row.
     */
    dataItem: any;
    /**
     * Contains an array of focusable cells associated with this row.
     */
    cells: NavigationCell[];
    /**
     * @hidden
     */
    groupItem?: GroupItem;
}
