/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef, NgZone } from '@angular/core';
import { PDFService } from './pdf.service';
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { ContextService } from '../common/provider.service';
import { ToolbarToolBase } from '../common/toolbar-tool-base.directive';
import * as i0 from "@angular/core";
/**
 * Represents the PDF export toolbar tool of the Grid.
 * Apply this directive to any `kendo-toolbar-button` element inside a ToolbarComponent in the Grid.
 * When you click the toolbar button with this directive, the [`pdfExport`]({% slug api_grid_gridcomponent %}#toc-pdfexport) event fires. ([See example]({% slug pdfexport_grid %})).
 *
 * @example
 * ```html
 * <kendo-grid>
 *      <kendo-toolbar>
 *         <kendo-toolbar-button text="Export to PDF" kendoGridPDFTool></kendo-toolbar-button>
 *      </kendo-toolbar>
 *      <kendo-grid-pdf fileName="products.pdf"></kendo-grid-pdf>
 * </kendo-grid>
 * ```
 * @remarks
 * Applied to: {@link ToolBarButtonComponent}.
 */
export declare class PDFCommandToolbarDirective extends ToolbarToolBase {
    private pdfService;
    host: ToolBarButtonComponent;
    constructor(pdfService: PDFService, host: ToolBarButtonComponent, ctx: ContextService, zone: NgZone, cdr: ChangeDetectorRef);
    ngOnInit(): void;
    /**
     * @hidden
     */
    onClick(e: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<PDFCommandToolbarDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<PDFCommandToolbarDirective, "[kendoGridPDFTool]", never, {}, {}, never, never, true, never>;
}
