/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2 as Renderer, NgZone } from '@angular/core';
import { Button } from '@progress/kendo-angular-buttons';
import { ContextService } from '../common/provider.service';
import { PDFService } from './pdf.service';
import * as i0 from "@angular/core";
/**
 * Represents the PDF export command of the Grid.
 * Apply this directive to any `button` element inside a [ToolbarTemplate]({% slug api_grid_commandcolumncomponent %}).
 * When you click a button with this directive, the [`pdfExport`]({% slug api_grid_gridcomponent %}#toc-pdfexport) event fires. ([See example]({% slug pdfexport_grid %})).
 *
 * @example
 * ```html
 * <kendo-grid>
 *      <ng-template kendoGridToolbarTemplate>
 *          <button kendoGridPDFCommand>Export to PDF</button>
 *      </ng-template>
 *      <kendo-grid-pdf fileName="products.pdf"></kendo-grid-pdf>
 * </kendo-grid>
 * ```
 */
export declare class PDFCommandDirective extends Button {
    private pdfService;
    /**
     * @hidden
     */
    onClick(e: any): void;
    /**
     * @hidden
     */
    get pdfClass(): boolean;
    constructor(pdfService: PDFService, element: ElementRef, renderer: Renderer, ctx: ContextService, ngZone: NgZone);
    static ɵfac: i0.ɵɵFactoryDeclaration<PDFCommandDirective, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PDFCommandDirective, "[kendoGridPDFCommand]", never, {}, {}, never, ["*"], true, never>;
}
