/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import { PDFExportTemplateDirective } from '@progress/kendo-angular-pdf-export';
import * as i0 from "@angular/core";
/**
 * The directive allows customizing the PDF page template for the Grid.
 * Place an `<ng-template>` with the `kendoGridPDFTemplate` directive inside the `<kendo-grid-pdf>` tag.
 *
 * The template context provides:
 * - `pageNumber`&mdash;The current PDF page number.
 * - `totalPages`&mdash;The total number of PDF pages.
 *
 * @example
 * ```html
 * <kendo-grid [data]="gridData">
 *   ...
 *   <kendo-grid-pdf fileName="Products.pdf" paperSize="A4">
 *     <ng-template kendoGridPDFTemplate let-pageNumber="pageNumber" let-totalPages="totalPages">
 *         Page {{ pageNumber }} of {{ totalPages }}
 *     </ng-template>
 *   </kendo-grid-pdf>
 * </kendo-grid>
 * ```
 */
export declare class PDFTemplateDirective extends PDFExportTemplateDirective {
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<PDFTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<PDFTemplateDirective, "[kendoGridPDFTemplate]", never, {}, {}, never, never, true, never>;
}
