/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * The directive allows customizing the loading indicator for virtual scrolling cells in the Grid.
 * Place an `<ng-template>` tag with the `kendoGridCellLoadingTemplate` directive inside `<kendo-grid>` to define the loading cell template. ([See example]({% slug virtualscrolling_grid %}#toc-custom-loading-skeleton)).
 *
 * The template context is set to the current column. You can use the following field:
 * - `column`&mdash;The current column instance. This is the default context for any template variable that uses the `let-x` syntax (for example, `let-column`).
 *
 * @example
 * ```html
 * <kendo-grid ... scrollable="virtual" [rowHeight]="36" [height]="450">
 *   <ng-template kendoGridCellLoadingTemplate let-column>
 *    ...
 *   </ng-template>
 * </kendo-grid>
 * ```
 */
export declare class CellLoadingTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<CellLoadingTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<CellLoadingTemplateDirective, "[kendoGridCellLoadingTemplate]", never, {}, {}, never, never, true, never>;
}
