/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Lets you customize the content of Grid cells.
 * Place an `<ng-template>` tag with the `kendoGridCellTemplate` directive inside a `<kendo-grid-column>` tag to define the cell template. ([See example](slug:templates_columns_grid#toc-cell-template)).
 *
 * The template context is set to the current data item. You can use these fields:
 * - `columnIndex`&mdash;The current column index. Use `let-columnIndex="columnIndex"` in your template.
 * - `rowIndex`&mdash;The current data row index. Use `let-rowIndex="rowIndex"` in your template.
 * - `dataItem`&mdash;The current data item. This is the default context for any template variable that uses the `let-x` syntax, such as `let-dataItem`.
 * - `column`&mdash;The current column instance. Use `let-column="column"` in your template.
 *
 * @example
 * ```html
 * <kendo-grid [data]="gridData" ...>
 *   <kendo-grid-column field="ProductName">
 *     <ng-template kendoGridCellTemplate let-dataItem let-rowIndex="rowIndex" let-column="column">
 *       Data Row: {{rowIndex}}
 *     </ng-template>
 *   </kendo-grid-column>
 * </kendo-grid>
 * ```
 */
export declare class CellTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<CellTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<CellTemplateDirective, "[kendoGridCellTemplate]", never, {}, {}, never, never, true, never>;
}
