/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI GridSpacer component for Angular.
 * Used to give additional white space between the Pager inner elements,
 * and provides a way for customizing the spacer width.
 * It can also be used in any flex container within the Grid
 * ([see example](slug:toolbartemplate_grid#toc-defining-the-spacing-between-toolbar-elements)).
 *
 * @example
 * ```html
 * <kendo-grid [data]="data">
 *   <ng-template kendoGridToolbarTemplate>
 *     <kendo-grid-spacer></kendo-grid-spacer>
 *       <button type="button" kendoGridExcelCommand [svgIcon]="fileExcelIcon"> Export to Excel </button>
 *     <kendo-grid-spacer></kendo-grid-spacer>
 *   </ng-template>
 *   <kendo-grid-column field="ProductName" title="Product Name"></kendo-grid-column>
 * </kendo-grid>
 * ```
 */
export declare class GridSpacerComponent {
    hostClass: boolean;
    get sizedClass(): boolean;
    get flexBasisStyle(): string;
    /**
     * Specifies the width of the GridSpacer.
     * Accepts string values for the [CSS `flex-basis`](https://developer.mozilla.org/en-US/docs/Web/CSS/flex-basis) property.
     * If not set, the GridSpacer takes all available space.
     */
    width: string;
    static ɵfac: i0.ɵɵFactoryDeclaration<GridSpacerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GridSpacerComponent, "kendo-grid-spacer", never, { "width": { "alias": "width"; "required": false; }; }, {}, never, never, true, never>;
}
