/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the column header cell template of the Grid
 * ([more information and example]({% slug templates_columns_grid %}#toc-header-template)).
 * Use this directive to customize the table header cell for a column.
 * To define a header template, nest an `<ng-template>` tag with the
 * `kendoGridHeaderTemplate` directive inside the `<kendo-grid-column>` tag.
 *
 * The template context is set to the current column. The following additional fields are available:
 * * `column`&mdash;An instance of the [`ColumnComponent`]({% slug api_grid_columncomponent %}) option.
 * * `columnIndex`&mdash;The current column index.
 *
 * @example
 * ```typescript
 * <kendo-grid>
 *   <kendo-grid-column field="ProductName" title="Product Name">
 *     <ng-template kendoGridHeaderTemplate let-column let-columnIndex="columnIndex">
 *       Header for {{ column.field }} (index: {{ columnIndex }})
 *     </ng-template>
 *   </kendo-grid-column>
 * </kendo-grid>
 * ```
 */
export declare class HeaderTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<HeaderTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<HeaderTemplateDirective, "[kendoGridHeaderTemplate]", never, {}, {}, never, never, true, never>;
}
