/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgZone, Renderer2, AfterViewInit, OnInit, OnDestroy, ChangeDetectorRef } from '@angular/core';
import { PopupService } from '@progress/kendo-angular-popup';
import { RefreshService, ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { ContextService } from '../../../common/provider.service';
import { AdaptiveGridService } from '../../../common/adaptiveness.service';
import { ColumnInfoService } from '../../../common/column-info.service';
import { ToolbarToolBase } from '../../../common/toolbar-tool-base.directive';
import * as i0 from "@angular/core";
/**
 * Represents a column chooser toolbar tool of the Grid.
 * Use this directive on any `kendo-toolbar-button` inside a ToolbarComponent in the Grid.
 *
 * @example
 * ```html-no-run
 * <kendo-grid>
 *      <kendo-toolbar>
 *         <kendo-toolbar-button kendoGridColumnChooserTool></kendo-toolbar-button>
 *      </kendo-toolbar>
 * </kendo-grid>
 * ```
 * @remarks
 * Applied to: {@link ToolBarButtonComponent}.
 */
export declare class ColumnChooserToolbarDirective extends ToolbarToolBase implements OnInit, AfterViewInit, OnDestroy {
    private renderer;
    private popupSerivce;
    host: ToolBarButtonComponent;
    ctx: ContextService;
    zone: NgZone;
    private refresh;
    private adaptiveGridService;
    private columnInfoService;
    /**
     * When `true`, changes to column visibility apply immediately.
     *
     * @default false
     */
    autoSync: boolean;
    /**
     * When `true`, enables the hiding of all columns.
     *
     * @default true
     */
    allowHideAll: boolean;
    /**
     * @hidden
     */
    get columns(): any;
    private popupRef;
    private subs;
    private actionSheetCloseSub;
    private nextId;
    constructor(renderer: Renderer2, popupSerivce: PopupService, host: ToolBarButtonComponent, ctx: ContextService, zone: NgZone, refresh: RefreshService, adaptiveGridService: AdaptiveGridService, columnInfoService: ColumnInfoService, cdr: ChangeDetectorRef);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    onClick(e: any): void;
    private togglePopup;
    private closePopup;
    private get buttonElement();
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnChooserToolbarDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ColumnChooserToolbarDirective, "[kendoGridColumnChooserTool]", never, { "autoSync": { "alias": "autoSync"; "required": false; }; "allowHideAll": { "alias": "allowHideAll"; "required": false; }; }, {}, never, never, true, never>;
}
