/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AfterViewInit, NgZone, OnDestroy, Renderer2 } from '@angular/core';
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { PopupService } from '@progress/kendo-angular-popup';
import { ContextService } from '../../../common/provider.service';
import { AdaptiveGridService } from '../../../common/adaptiveness.service';
import * as i0 from "@angular/core";
/**
 * Represents the toolbar tool for grouping columns of the Grid.
 * Use this directive on any `kendo-toolbar-button` inside a ToolbarComponent in the Grid.
 * When you click the toolbar button with this directive, the `group` event is triggered.
 *
 * @example
 * ```html
 * <kendo-grid>
 *      <kendo-toolbar>
 *         <kendo-toolbar-button text="Group" kendoGridGroupTool></kendo-toolbar-button>
 *      </kendo-toolbar>
 * </kendo-grid>
 * ```
 * @remarks
 * Applied to: {@link ToolBarButtonComponent}.
 */
export declare class GroupCommandToolbarDirective implements AfterViewInit, OnDestroy {
    private host;
    private popupService;
    private ctx;
    private ngZone;
    private renderer;
    private adaptiveGridService;
    private popupRef;
    private nextId;
    private toolSubs;
    private popupSubs;
    private actionSheetCloseSub;
    private removeClickListener;
    constructor(host: ToolBarButtonComponent, popupService: PopupService, ctx: ContextService, ngZone: NgZone, renderer: Renderer2, adaptiveGridService: AdaptiveGridService);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    private onClick;
    private openPopup;
    private setPopupAttributes;
    private initPopupProperties;
    private closePopup;
    private get buttonElement();
    private isGroupingApplied;
    static ɵfac: i0.ɵɵFactoryDeclaration<GroupCommandToolbarDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<GroupCommandToolbarDirective, "[kendoGridGroupTool]", never, {}, {}, never, never, true, never>;
}
