/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * The directive allows customizing the drag handle cell in the Grid row reorder column.
 * Place an `<ng-template>` tag with the `kendoGridRowDragHandleTemplate` directive inside the `<kendo-grid-rowreorder-column>` tag to set the cell template.
 *
 * The template context is the current data item. You also get access to the following additional fields:
 * - `columnIndex`&mdash;The current column index. Use it as a template variable with `let-columnIndex="columnIndex"`.
 * - `rowIndex`&mdash;The data row index. Use it as a template variable with `let-rowIndex="rowIndex"`.
 *
 * @example
 * ```html
 * <kendo-grid [kendoGridBinding]="data" [rowReorderable]="true">
 *    <kendo-grid-rowreorder-column>
 *      <ng-template kendoGridRowDragHandleTemplate>
 *        <span>Drag here</span>
 *      </ng-template>
 *    </kendo-grid-rowreorder-column>
 *   <kendo-grid-column field="Field1"></kendo-grid-column>
 *   <kendo-grid-column field="Field2"></kendo-grid-column>
 * </kendo-grid>
 * ```
 */
export declare class RowDragHandleTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<RowDragHandleTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RowDragHandleTemplateDirective, "[kendoGridRowDragHandleTemplate]", never, {}, {}, never, never, true, never>;
}
