/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Subject } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * Defines the arguments for the `scrollTo` method. Use this to specify the row or column to scroll to.
 * [See example](slug:scrollmmodes_grid#toc-scrolling-to-a-specific-row-and-column).
 */
export interface ScrollRequest {
    /**
     * Specifies the row index to scroll to. The first row has index `0`.
     */
    row?: number;
    /**
     * Specifies the column index to scroll to. The first column has index `0`.
     */
    column?: number;
}
/**
 * Defines the arguments for the `scrollToItem` method. Use this to specify the data item and column to scroll to.
 * [See example](slug:scrollmmodes_grid#toc-scrolling-to-a-specific-item).
 */
export interface ScrollToItemRequest {
    /**
     * Specifies the property name in the Grid data items that holds the unique ID.
     */
    idField: string;
    /**
     * Specifies the value of the unique identifier for the data item.
     */
    id: any;
}
/**
 * @hidden
 */
export declare class ScrollRequestService {
    requests: Subject<{
        request: ScrollRequest | ScrollToItemRequest;
        adjustIndex?: boolean;
    }>;
    scrollTo(request: ScrollRequest, adjustIndex?: boolean): void;
    scrollToItem(request: ScrollToItemRequest): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ScrollRequestService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ScrollRequestService>;
}
