/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { State } from "@progress/kendo-data-query";
import { GridDataResult } from "../data/data.collection";
import { PreventableEvent } from "@progress/kendo-angular-common";
/**
 * Describes the state of a Grid column that users can change.
 */
export interface ColumnState {
    /**
     * The column identifier that is unique in the scope of its `GridComponent` owner.
     */
    id: string;
    /**
     * The column width in pixels.
     */
    width?: number;
    /**
     * The column visibility state.
     */
    hidden?: boolean;
    /**
     * The column locked state.
     */
    locked?: boolean;
    /**
     * The column sticky state.
     */
    sticky?: boolean;
    /**
     * The order index of the column.
     */
    orderIndex?: number;
}
/**
 * Describes the state of the Grid component.
 * Includes the current `State`, data, and columns state.
 */
export interface GridState extends State {
    /**
     * The state of all columns in the Grid.
     */
    columnsState?: ColumnState[];
    /**
     * The current data in the Grid.
     */
    currentData?: Array<any> | GridDataResult | null;
}
/**
 * Provides arguments for the `undo` and `redo` events.
 */
export declare class UndoRedoEvent extends PreventableEvent {
    /**
     * The event data for the action that changed the state.
     */
    readonly originalEvent: any;
    /**
     * The Grid state and rendered data at the time of the action.
     */
    readonly gridState: GridState;
    /**
     * @hidden
     */
    constructor({ originalEvent, gridState }: any);
}
